@@ -58,12 +58,13 @@ protected:
 
   virtual QString projectDirectory() const;
   virtual QString projectName() const;
-  virtual QString mainProgram(bool relative = false) const;
+  virtual QString mainProgram() const;
   virtual QString activeDirectory() const;
   virtual QStringList allFiles() const;
   virtual QString buildDirectory() const;
   virtual QString runDirectory() const;
   virtual QString runArguments() const;
+  virtual QString debugArguments() const;
   virtual DomUtil::PairList runEnvironmentVars() const;
 
   virtual void addFile(const QString &fileName);
