@@ -30,6 +30,7 @@
 #include <qregexp.h>
 #include <qgroupbox.h>
 
+
 #include <kaction.h>
 #include <kdebug.h>
 #include <kdialogbase.h>
@@ -52,6 +53,7 @@
 
 #include <configwidgetproxy.h>
 #include <kdevplugininfo.h>
+#include <urlutil.h>
 
 #define CONFIGURE_OPTIONS 1
 #define RUN_OPTIONS 2
@@ -205,8 +207,7 @@ AutoProjectPart::AutoProjectPart(QObject *parent, const char *name, const QStrin
                               this, SLOT(slotExecute()),
                               actionCollection(), "build_execute" );
         action->setToolTip(i18n("Execute program"));
-        action->setWhatsThis(i18n("<b>Execute program</b><p>Executes the main program specified in project settings, <b>Run Options</b> tab. "
-                                  "If it is not specified then the active target is used to determine the application to run."));
+        action->setWhatsThis(i18n("<b>Execute program</b><p>Executes the currently active target or the main program specified in project settings, <b>Run Options</b> tab."));
         action->setGroup("autotools");
     }
 
@@ -265,7 +266,6 @@ void AutoProjectPart::insertConfigWidget( const KDialogBase* dlg, QWidget * page
             {
                 //ok we handle the execute in this kpart
                 RunOptionsWidget *w3 = new RunOptionsWidget(*projectDom(), "/kdevautoproject", buildDirectory(), page );
-                w3->programGroupBox->setTitle(i18n("Program (if empty automatically uses active target and active target's arguments)"));
                 connect( dlg, SIGNAL(okClicked()), w3, SLOT(accept()) );
             }
         }
@@ -292,10 +292,12 @@ void AutoProjectPart::openProject(const QString &dirName, const QString &project
     kdDebug(9020) << k_funcinfo << "activeTarget " << activeTarget << endl;
     if (!activeTarget.isEmpty())
         m_widget->setActiveTarget(activeTarget);
-
-    // Set the default directory radio to "executable"
-    if (!DomUtil::readBoolEntry(dom, "/kdevautoproject/run/disable_default") && DomUtil::readEntry(dom, "/kdevautoproject/run/directoryradio") == "" ) {
-        DomUtil::writeEntry(dom, "/kdevautoproject/run/directoryradio", "executable");
+    else
+    {
+        KMessageBox::information( m_widget, "No active target specified, running the application will\n"
+                                   "not work until you make a target active in the Automake Manager\n"
+                                   "on the right side or use the Main Program options under\n"
+                                   "Project -> Project Options -> Run Options", "No active target specified",  "kdevelop_open_project_no_active_target");
     }
 
     KDevProject::openProject( dirName, projectName );
@@ -340,7 +342,21 @@ DomUtil::PairList AutoProjectPart::runEnvironmentVars() const
   */
 QString AutoProjectPart::runDirectory() const
 {
-    return defaultRunDirectory("kdevautoproject");
+
+    QDomDocument &dom = *projectDom();
+
+    QString cwd;
+    if( DomUtil::readBoolEntry(dom, "/kdevautoproject/run/useglobalprogram", false) || !m_widget->activeTarget() )
+    {
+        cwd = defaultRunDirectory("kdevautoproject");
+    }else
+    {
+        cwd = DomUtil::readEntry( dom, "/kdevautoproject/run/cwd/"+m_widget->activeTarget()->name );
+    }
+    if( cwd.isEmpty() )
+        cwd = buildDirectory() +"/"+ URLUtil::getRelativePath( topsourceDirectory(), projectDirectory() ) +"/"+m_widget->activeDirectory();
+
+    return cwd;
 }
 
 
@@ -355,53 +371,71 @@ QString AutoProjectPart::runDirectory() const
   *   if /kdevautoproject/run/directoryradio == custom or relative == false
   *        The absolute path to executable
   */
-QString AutoProjectPart::mainProgram(bool relative) const
+
+QString AutoProjectPart::mainProgram() const
 {
-    QDomDocument &dom = *projectDom();
+    QDomDocument * dom = projectDom();
 
-    QString directoryRadioString = DomUtil::readEntry(dom, "/kdevautoproject/run/directoryradio");
-    QString DomMainProgram = DomUtil::readEntry(dom, "/kdevautoproject/run/mainprogram");
+    if ( !dom ) return QString();
 
-    if ( DomMainProgram.isEmpty() ) {
-    // If no Main Program was specified, return the active target
+    if( DomUtil::readBoolEntry(*dom, "/kdevautoproject/run/useglobalprogram", false) )
+    {
+        QString DomMainProgram = DomUtil::readEntry(*dom, "/kdevautoproject/run/mainprogram");
 
-        // Get a pointer to the active target
+        if ( DomMainProgram.isEmpty() ) return QString();
+
+        if ( DomMainProgram.startsWith("/") )   // assume absolute path
+        {
+            return DomMainProgram;
+        }
+        else // assume builddir relative path
+        {
+            QString relprojectpath = URLUtil::getRelativePath( topsourceDirectory(), projectDirectory() );
+            if( !relprojectpath.isEmpty() )
+                relprojectpath = "/" + relprojectpath;
+            return buildDirectory() + relprojectpath + "/" + DomMainProgram;
+        }
+
+    }
+    else // If no Main Program was specified, return the active target
+    {
         TargetItem* titem = m_widget->activeTarget();
 
         if ( !titem ) {
-            kdDebug ( 9020 ) << k_funcinfo << "Error! : No Main Program was specified and there's no active target! -> Unable to determine the main program in AutoProjectPart::mainProgram()" << endl;
+            KMessageBox::error( m_widget, "There's no active target!\n"
+                                "Unable to determine the main program", "No active target found" );
+            kdDebug ( 9020 ) << k_funcinfo << "Error! : There's no active target! -> Unable to determine the main program in AutoProjectPart::mainProgram()" << endl;
             return QString::null;
         }
 
         if ( titem->primary != "PROGRAMS" ) {
-            kdDebug ( 9020 ) << k_funcinfo << "Error! : No Main Program was specified and active target isn't binary (" << titem->primary << ") ! -> Unable to determine the main program in AutoProjectPart::mainProgram()" << endl;
+            KMessageBox::error( m_widget, "Active target \""+titem->name+"\"isn't binary ( " + titem->primary + " ) !\n"
+                                "Unable to determine the main program. If you want this\n"
+                                "to be the active target, set a main program under\n"
+                                "Project -> Project Options -> Run Options", "Active target is not a library" );
+            kdDebug ( 9020 ) << k_funcinfo << "Error! : Active target isn't binary (" << titem->primary << ") ! -> Unable to determine the main program in AutoProjectPart::mainProgram()" << endl;
             return QString::null;
         }
 
-        if (relative == false || directoryRadioString == "custom")
-            return buildDirectory() + "/" + activeDirectory() + "/" + titem->name;
-
-        if ( directoryRadioString == "executable" )
-            return titem->name;
-
-        return activeDirectory() + "/" + titem->name;
-
+        QString relprojectpath = URLUtil::getRelativePath( topsourceDirectory(), projectDirectory() );
+        if( !relprojectpath.isEmpty() )
+            relprojectpath = "/" + relprojectpath;
+        return buildDirectory() + relprojectpath + "/" + activeDirectory() + "/" + titem->name;
     }
-    else {
-    // A Main Program was specified, return it
-        if ( directoryRadioString == "custom" )
-            return DomMainProgram;
+}
 
-        if ( relative == false )
-            return buildDirectory() + "/" + DomMainProgram;
 
-        if ( directoryRadioString != "executable" )
-            return DomMainProgram;
+/** Retuns a QString with the debug command line arguments */
+QString AutoProjectPart::debugArguments() const
+{
+    QDomDocument &dom = *projectDom();
 
-        int pos = DomMainProgram.findRev('/');
-        if (pos != -1)
-            return DomMainProgram.mid(pos+1);
-        return DomMainProgram;
+    if( DomUtil::readBoolEntry(dom, "/kdevautoproject/run/useglobalprogram", false) || !m_widget->activeTarget() )
+    {
+        return DomUtil::readEntry(dom, "/kdevautoproject/run/globaldebugarguments");
+    }else
+    {
+        return DomUtil::readEntry(dom, "/kdevautoproject/run/debugarguments/" + m_widget->activeTarget()->name);
     }
 }
 
@@ -411,17 +445,13 @@ QString AutoProjectPart::runArguments() const
 {
     QDomDocument &dom = *projectDom();
 
-    QString DomMainProgram = DomUtil::readEntry(dom, "/kdevautoproject/run/mainprogram");
-    QString DomProgramArguments = DomUtil::readEntry(*projectDom(), "/kdevautoproject/run/programargs");
-
-    if ( DomMainProgram.isEmpty() && DomProgramArguments.isEmpty() )
-    // If no "Main Program" and no "Program Arguments" were specified, return the active target's run arguments
-        if (m_widget->activeTarget())
-            return DomUtil::readEntry(*projectDom(), "/kdevautoproject/run/runarguments/" + m_widget->activeTarget()->name);
-        else
-            return QString::null;
-    else
-        return DomProgramArguments;
+    if( DomUtil::readBoolEntry(dom, "/kdevautoproject/run/useglobalprogram", false) || !m_widget->activeTarget() )
+    {
+        return DomUtil::readEntry(dom, "/kdevautoproject/run/programargs");
+    }else
+    {
+        return DomUtil::readEntry(dom, "/kdevautoproject/run/runarguments/" + m_widget->activeTarget()->name);
+    }
 }
 
 
@@ -604,9 +634,9 @@ QString AutoProjectPart::constructMakeCommandLine(const QString &dir, const QStr
     {
         if (!QFile::exists(buildDirectory() + "/configure"))
         {
-            int r = KMessageBox::questionYesNo(m_widget, i18n("There is no Makefile in this directory\n"
+            int r = KMessageBox::questionYesNo(m_widget, i18n("%1\nThere is no Makefile in this directory\n"
                                                "and no configure script for this project.\n"
-                                               "Run automake & friends and configure first?"), QString::null, i18n("Run Them"), i18n("Do Not Run"));
+                                               "Run automake & friends and configure first?").arg(buildDirectory()), QString::null, i18n("Run Them"), i18n("Do Not Run"));
             if (r == KMessageBox::No)
                 return QString::null;
             preCommand = makefileCvsCommand();
@@ -617,7 +647,7 @@ QString AutoProjectPart::constructMakeCommandLine(const QString &dir, const QStr
         }
         else
         {
-            int r = KMessageBox::questionYesNo(m_widget, i18n("There is no Makefile in this directory. Run 'configure' first?"), QString::null, i18n("Run configure"), i18n("Do Not Run"));
+            int r = KMessageBox::questionYesNo(m_widget, i18n("%1\nThere is no Makefile in this directory. Run 'configure' first?").arg(dir), QString::null, i18n("Run configure"), i18n("Do Not Run"));
             if (r == KMessageBox::No)
                 return QString::null;
             preCommand = configureCommand() + " && ";
@@ -810,7 +840,7 @@ void AutoProjectPart::slotBuildActiveTarget()
     return;
 
   // build it
-  buildTarget(activeDirectory(), titem);
+  buildTarget( URLUtil::getRelativePath( topsourceDirectory(), projectDirectory() ) + "/" + activeDirectory(), titem);
 }
 
 
@@ -1016,20 +1046,21 @@ void AutoProjectPart::slotExecute()
     partController()->saveAllFiles();
     QDomDocument &dom = *projectDom();
 
-    m_runProg=m_runProg.isEmpty()?mainProgram(false):m_runProg;
+    m_runProg=m_runProg.isEmpty()?mainProgram():m_runProg;
 
     bool _auto = false;
     if( DomUtil::readBoolEntry(dom, "/kdevautoproject/run/autocompile", true) && isDirty() ){
         m_executeAfterBuild = true;
-        if ( DomUtil::readEntry(dom, "/kdevautoproject/run/mainprogram").isEmpty() ){
-        // If no Main Program was specified, build the active target
-            kdDebug(9020) << "slotExecute: before slotBuildActiveTarget" << endl;
-            slotBuildActiveTarget();
-        }
-        else{
-        // A Main Program was specified, build all targets because we don't know which is it
+        if ( DomUtil::readBoolEntry(dom, "/kdevautoproject/run/useglobalprogram", false) ){
+          // A Main Program was specified, build all targets because we don't know which is it
             kdDebug(9020) << "slotExecute: before slotBuild" << endl;
             slotBuild();
+
+        }
+        else{
+          // If no Main Program was specified, build the active target
+            kdDebug(9020) << "slotExecute: before slotBuildActiveTarget" << endl;
+            slotBuildActiveTarget();
         }
         _auto = true;
     }
@@ -1088,7 +1119,7 @@ void AutoProjectPart::executeTarget(const QDir& dir, const TargetItem* titem)
         m_executeTargetAfterBuild.first = dir;
         m_executeTargetAfterBuild.second = const_cast<TargetItem*>(titem);
 
-        QString relpath = dir.path().mid( projectDirectory().length() );
+        QString relpath = "/" + URLUtil::getRelativePath( topsourceDirectory(), projectDirectory() ) + "/" + m_widget->selectedSubproject()->subdir;
         kdDebug(9020) << "executeTarget: before buildTarget " << relpath << endl;
         buildTarget(relpath, const_cast<TargetItem*>(titem));
         return;
@@ -1098,9 +1129,21 @@ void AutoProjectPart::executeTarget(const QDir& dir, const TargetItem* titem)
     bool inTerminal = DomUtil::readBoolEntry(*projectDom(), "/kdevautoproject/run/terminal");
 
     QString program = environString();
-    if(!titem->name.startsWith("/"))
-        program += "./";
-    program += titem->name;
+
+    if ( !titem ) {
+        KMessageBox::error( m_widget, "There's no active target!\n"
+                                "Unable to determine the main program", "No active target found" );
+        kdDebug ( 9020 ) << k_funcinfo << "Error! : There's no active target! -> Unable to determine the main program in AutoProjectPart::mainProgram()" << endl;
+        program += titem->name;
+    }else if ( titem->primary != "PROGRAMS" ) {
+        KMessageBox::error( m_widget, "Active target \""+titem->name+"\"isn't binary ( " + titem->primary + " ) !\n"
+                                "Unable to determine the main program. If you want this\n"
+                                "to be the active target, set a main program under\n"
+                                "Project -> Project Options -> Run Options", "Active target is not a library" );
+        kdDebug ( 9020 ) << k_funcinfo << "Error! : Active target isn't binary (" << titem->primary << ") ! -> Unable to determine the main program in AutoProjectPart::mainProgram()" << endl;
+        program += titem->name;
+    }else
+        program += buildDirectory() + "/" + URLUtil::getRelativePath( topsourceDirectory(), projectDirectory() ) + "/" + m_widget->selectedSubproject()->relativePath()+ "/" + titem->name;
 
     QString args = DomUtil::readEntry(*projectDom(), "/kdevautoproject/run/runarguments/" + titem->name);
 
@@ -1179,7 +1222,7 @@ void AutoProjectPart::slotExecute2()
 
     kdDebug(9020) << "slotExecute2: runDirectory: <" << runDirectory() << ">" <<endl;
     kdDebug(9020) << "slotExecute2: environstr  : <" << environString() << ">" <<endl;
-    kdDebug(9020) << "slotExecute2: mainProgram : <" << mainProgram(true) << ">" <<endl;
+    kdDebug(9020) << "slotExecute2: mainProgram : <" << mainProgram() << ">" <<endl;
     kdDebug(9020) << "slotExecute2: runArguments: <" << runArguments() << ">" <<endl;
     kdDebug(9020) << "slotExecute2: program     : <" << program << ">" <<endl;
 
