@@ -1,6 +1,8 @@
 /***************************************************************************
  *   Copyright (C) 2001-2002 by Bernd Gehrmann                             *
  *   bernd@kdevelop.org                                                    *
+ *   Copyright (C) 2007 by Andreas Pakulat                                 *
+ *   apaku@gmx.de                                                          *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -24,6 +26,7 @@ class QListViewItem;
 class QPopupMenu;
 class QStringList;
 class KDialogBase;
+class KDirWatch;
 class CustomProjectWidget;
 class Context;
 class KSelectAction;
@@ -42,8 +45,7 @@ public:
     bool isDirty();
     QStringList distFiles() const;
 
-protected:
-    virtual void openProject(const QString &dirName, const QString &projectName);
+    virtual void openProject( const QString &dirName, const QString &projectName );
     virtual void closeProject();
 
     virtual QString projectDirectory() const;
@@ -51,10 +53,10 @@ protected:
     virtual QString mainProgram() const;
     virtual QString activeDirectory() const;
     virtual QStringList allFiles() const;
-    virtual void addFile(const QString &fileName);
-    virtual void addFiles ( const QStringList& fileList );
-    virtual void removeFile(const QString &fileName);
-    virtual void removeFiles ( const QStringList &fileList );
+    virtual void addFile( const QString &fileName );
+    virtual void addFiles( const QStringList& fileList );
+    virtual void removeFile( const QString &fileName );
+    virtual void removeFiles( const QStringList &fileList );
     virtual QString buildDirectory() const;
     virtual QString runDirectory() const;
     virtual QString debugArguments() const;
@@ -63,38 +65,61 @@ protected:
 
 
 private slots:
-    void projectConfigWidget(KDialogBase *dlg);
-    void contextMenu(QPopupMenu *popup, const Context *context);
+    void populateProject();
+    void slotDirDirty( const QString& dir );
+    void projectConfigWidget( KDialogBase *dlg );
+    void contextMenu( QPopupMenu *popup, const Context *context );
     void slotAddToProject();
     void slotRemoveFromProject();
+    void slotAddToProjectRecursive();
+    void slotRemoveFromProjectRecursive();
+    void addNewFilesToProject();
+    void slotChangeBlacklist();
     void slotChooseActiveDirectory();
     void slotBuild();
+    void slotBuildActiveDir();
     void slotCompileFile();
     void slotInstall();
+    void slotInstallActiveDir();
     void slotInstallWithKdesu();
     void slotClean();
     void slotExecute();
     void updateTargetMenu();
-    void targetMenuActivated(int id);
-    void targetObjectFilesMenuActivated(int id);
-    void targetOtherFilesMenuActivated(int id);
+    void targetMenuActivated( int id );
+    void targetObjectFilesMenuActivated( int id );
+    void targetOtherFilesMenuActivated( int id );
     void updateMakeEnvironmentsMenu();
-    void makeEnvironmentsMenuActivated(int id);
+    void makeEnvironmentsMenuActivated( int id );
     void slotCommandFinished( const QString& command );
     void slotCommandFailed( const QString& command );
 
 private:
-    void populateProject();
+    bool containsNonProjectFiles( const QString& url );
+    QStringList projectFilesInDir( const QString& dir );
+    bool containsProjectFiles( const QString& url );
+    bool isProjectFileType( const QString& absFile ) const;
+    bool isInBlacklist( const QString& ) const;
+    void cleanFileList();
+    void setFiletypes( const QStringList& );
+    QString relativeToProject( const QString& ) const;
+    void addDirWatches( const QString& );
+    void findNewFiles( const QString& dir, QStringList& list) const;
+
+    QStringList filetypes() const;
+    QStringList blacklist() const;
+    void updateBlacklist( const QStringList& );
     void saveProject();
     void startMakeCommand( const QString &dir, const QString &target, bool withKdesu = false );
-    void parseMakefile(const QString& file);
+    void parseMakefile( const QString& file );
     QString makeEnvironment() const;
     void putEnvVarsInVarMap();
+    void switchBlacklistEntry(const QString& );
 
     QString m_projectDirectory;
     QString m_projectName;
     QString m_filelistDir;
     QStringList m_sourceFiles;
+    QStringList m_autoAddFiles;
     QPopupMenu *m_targetMenu;
     QPopupMenu *m_targetObjectFilesMenu;
     QPopupMenu *m_targetOtherFilesMenu;
@@ -113,6 +138,10 @@ private:
     QMap<QString, int> m_parsedMakefiles;
     QValueStack<QString> m_makefilesToParse;
     QMap<QString, QString> m_makefileVars;
+    bool m_recursive;
+    bool m_first_recursive;
+    KDirWatch* dirwatch;
 };
 
 #endif
+// kate: space-indent on; indent-width 4; tab-width 4; replace-tabs on
