@@ -13,13 +13,13 @@
 
 #include <qguardedptr.h>
 
-#include "kdevproject.h"
+#include "kdevbuildtool.h"
 
 class PascalProjectWidget;
 class KDialogBase;
 class KDevCompilerOptions;
 
-class PascalProjectPart : public KDevProject
+class PascalProjectPart : public KDevBuildTool
 {
     Q_OBJECT
 public:
@@ -31,7 +31,7 @@ public:
 
     /**Returns the name of the main source file without extension.
     All pascal compilers call the binary by that way*/
-    virtual QString mainProgram(bool relative = false) const;
+    virtual QString mainProgram() const;
     /**Main source file (like src/main.pp)*/
     virtual QString mainSource() const;
     virtual void setMainSource(QString fullPath);
@@ -42,6 +42,7 @@ public:
     /**The location of the main source file*/
     virtual QString buildDirectory() const;
     virtual QString runDirectory() const;
+    virtual QString debugArguments() const;
     virtual QString runArguments() const;
     virtual DomUtil::PairList runEnvironmentVars() const;
 
