@@ -23,6 +23,9 @@
 
 #include <kdirwatch.h>
 
+#include <kmessagebox.h>
+#include <klocale.h>
+
 #include "urlutil.h"
 #include "trollprojectpart.h"
 #include "qmakedefaultopts.h"
@@ -65,7 +68,6 @@ Scope::~Scope()
     m_scopes.clear();
 
     m_customVariables.clear();
-
     if ( m_root && m_root->isProject() && !m_incast )
     {
         delete m_root;
@@ -117,16 +119,18 @@ Scope::Scope( unsigned int num, Scope* parent, QMake::IncludeAST* incast, const
     m_part(part), m_defaultopts(defaultopts)
 {
     QString absfilename;
-    QString tmp;
-    if( incfile.contains(")" ) )
-        tmp = incfile.mid(0, incfile.find(")") );
-    else
-        tmp = incfile;
+    QString tmp = incfile.stripWhiteSpace();
+    if( tmp.contains(")" ) )
+        tmp = tmp.mid(0, tmp.find(")") );
+
+    if( tmp.startsWith( "\"" ) )
+        tmp = tmp.mid( 1, tmp.length()-2 );
+
     if( QFileInfo(tmp).isRelative() )
     {
-        absfilename = path + QString( QChar( QDir::separator() ) ) + tmp;
+        absfilename = QDir::cleanDirPath( path + QString( QChar( QDir::separator() ) ) + tmp );
     }else
-        absfilename = tmp;
+        absfilename = QDir::cleanDirPath( tmp );
     if ( !loadFromFile( absfilename ) )
     {
         if( !QFileInfo( absfilename ).exists() && QFileInfo( QFileInfo( absfilename ).dirPath( true ) ).exists() )
@@ -147,9 +151,11 @@ Scope::Scope( unsigned int num, Scope* parent, QMake::IncludeAST* incast, const
 
 bool Scope::loadFromFile( const QString& filename )
 {
-    if ( !QFileInfo(filename).exists() || QMake::Driver::parseFile( filename, &m_root ) != 0 )
+    if ( !QFileInfo(filename).exists() || QMake::Driver::parseFile( filename, &m_root, 0 ) != 0 )
     {
         kdDebug( 9024 ) << "Couldn't parse project: " << filename << endl;
+        KMessageBox::error( 0, i18n( "Couldn't parse project file: %1" ).arg( filename ),
+                i18n( "Couldn't parse project file" ) );
         m_root = 0;
         return false;
     }
@@ -185,6 +191,10 @@ void Scope::saveToFile() const
         m_root->writeBack( astbuffer );
         out << astbuffer;
         file.close();
+    }else
+    {
+        KMessageBox::error( 0, i18n( "Couldn't write project file: %1" ).arg( filename ),
+                i18n( "Couldn't write project file" ) );
     }
 #ifdef DEBUG
     Scope::PrintAST pa;
@@ -289,9 +299,7 @@ QStringList Scope::variableValuesForOp( const QString& variable , const QString&
             }
         }
     }
-    result.remove( "\\\n" );
-    result.remove( "\n" );
-    result = Scope::removeWhiteSpace(result);
+    result = cleanStringList(result);
     return result;
 }
 
@@ -308,9 +316,7 @@ QStringList Scope::variableValues( const QString& variable, bool checkIncParent
     }
 
     calcValuesFromStatements( variable, result, checkIncParent );
-    result.remove( "\\\n" );
-    result.remove( "\n" );
-    result = Scope::removeWhiteSpace(result);
+    result = cleanStringList(result);
     if( scopeType() != Scope::IncludeScope || checkIncParent )
     {
         m_varCache[ variable ] = result;
@@ -375,8 +381,7 @@ void Scope::calcValuesFromStatements( const QString& variable, QStringList& resu
         }
     }
 
-    result.remove( "\\\n" );
-    result.remove( "\n" );
+    result = cleanStringList( result );
     return ;
 }
 
@@ -693,43 +698,52 @@ void Scope::updateValues( QStringList& origValues, const QStringList& newValues,
     {
         if ( origValues.findIndex( *it ) == -1 && !remove )
         {
-            while ( !origValues.isEmpty() && origValues.last() == "\n" )
+            while ( !origValues.isEmpty() && origValues.last() == getLineEndingString() )
                 origValues.pop_back();
-            if ( origValues.count() > 0 && origValues.last() != "\\\n" )
+            if ( origValues.count() > 0 && !containsContinue( origValues.last() ) && !isComment( origValues.last() ) )
             {
                 origValues.append( " " );
-                origValues.append( "\\\n" );
+                origValues.append( "\\"+getLineEndingString() );
                 if( indent != "" )
                     origValues.append( indent );
-            }else if ( !origValues.isEmpty() && origValues.last() == "\\\n" )
+            }else if ( !origValues.isEmpty() && containsContinue( origValues.last() ) && !isComment( origValues.last() ) )
             {
                 if( indent != "" )
                     origValues.append( indent );
+            }else if ( !origValues.isEmpty() && isComment( origValues.last() ) )
+            {
+                origValues[origValues.count()-1] = "\\ "+origValues[origValues.count()-1];
+                if( indent != "" )
+                    origValues.append( indent );
             }else if ( origValues.isEmpty() )
                 origValues.append(" ");
             QString newval = *it;
             QRegExp re("([^$])\\$([^$\\(\\)\\{\\} /]*)( |\\)|/)");
-            newval.replace(re, "\1$(\\2)\\3");
-            if( (newval).contains(" ") || (newval).contains("\t") || (newval).contains("\n") )
+            newval.replace(re, "\\1$(\\2)\\3");
+            if( (newval).contains(" ") || (newval).contains("\t") || (newval).contains( getLineEndingString() ) || (newval).contains("#") )
                 origValues.append( "\""+newval+"\"" );
             else
                 origValues.append( newval );
-            origValues.append( "\n" );
+            origValues.append( getLineEndingString() );
         } else if ( origValues.findIndex( *it ) != -1 && remove )
         {
             QStringList::iterator posit = origValues.find( *it );
             posit = origValues.remove( posit );
-            while( posit != origValues.end() && ( *posit == "\\\n" || (*posit).stripWhiteSpace() == "" ) )
+            while( posit != origValues.end() && ( (*posit).find( QRegExp("\\\\[\\s]*"+getLineEndingString() ) ) != -1
+                    || (*posit).stripWhiteSpace() == "" ) )
             {
                 posit = origValues.remove( posit );
             }
         }
     }
-    while( !origValues.isEmpty() && (origValues.last() == "\\\n"
-            || origValues.last() == "\n"
+    while( !origValues.isEmpty() && (origValues.last() == "\\"+getLineEndingString()
+            || origValues.last() == getLineEndingString()
             || origValues.last().stripWhiteSpace() == "" ) && !origValues.isEmpty() )
         origValues.pop_back();
-    origValues.append("\n");
+    if( !origValues.isEmpty() && origValues.last().find( QRegExp("\\\\[ \t]*#") ) != -1 )
+        origValues[origValues.count()-1] = origValues[origValues.count()-1].mid(origValues[origValues.count()-1].find( "#") );
+    if( !origValues.isEmpty() && origValues.last().find( getLineEndingString() ) == -1 )
+        origValues.append(getLineEndingString());
 }
 
 void Scope::updateVariable( const QString& variable, const QString& op, const QStringList& values, bool removeFromOp )
@@ -821,9 +835,9 @@ void Scope::updateVariable( const QString& variable, const QString& op, const QS
         else
             ast->setDepth( m_root->depth()+1 );
         m_root->addChildAST( ast );
-        if ( values.findIndex( "\n" ) == -1 )
+        if ( values.findIndex( getLineEndingString() ) == -1 )
         {
-            ast->values.append("\n");
+            ast->values.append( getLineEndingString() );
         }
     }
 }
@@ -869,7 +883,7 @@ void Scope::init()
         {
             QMake::IncludeAST * i = static_cast<QMake::IncludeAST*>( *it );
             QString filename = i->projectName;
-            if( i->projectName.startsWith("$") )
+            if( i->projectName.stripWhiteSpace().startsWith("$") )
             {
                 filename = resolveVariables(i->projectName, *it);
             }
@@ -884,7 +898,7 @@ void Scope::init()
                 for ( QStringList::const_iterator sit = m->values.begin() ; sit != m->values.end(); ++sit )
                 {
                     QString str = *sit;
-                    if ( str == "\\\n" || str == "\n" || str == "." || str == "./" || (str).stripWhiteSpace() == "" )
+                    if ( containsContinue( str ) || isComment( str ) || str == getLineEndingString() || str == "." || str == "./" || (str).stripWhiteSpace() == "" )
                         continue;
                     QDir subproject;
                     QString projectfile;
@@ -1101,13 +1115,16 @@ bool Scope::listsEqual(const QStringList& l1, const QStringList& l2)
     return (left == right);
 }
 
-QStringList Scope::removeWhiteSpace(const QStringList& list)
+QStringList Scope::cleanStringList(const QStringList& list) const
 {
     QStringList result;
     for( QStringList::const_iterator it = list.begin(); it != list.end(); ++it )
     {
         QString s = *it;
-        if( s.stripWhiteSpace() != "" )
+        if( s.stripWhiteSpace() != ""
+                && !containsContinue(s)
+                && s.stripWhiteSpace() != getLineEndingString()
+                && !isComment(s) )
             result.append(s);
     }
     return result;
@@ -1199,9 +1216,7 @@ QStringList Scope::variableValues( const QString& variable, QMake::AST* stopHere
         return result;
 
     calcValuesFromStatements( variable, result, true, stopHere );
-    result.remove( "\\\n" );
-    result.remove( "\n" );
-    result = Scope::removeWhiteSpace(result);
+    result = cleanStringList(result);
     return result;
 }
 
@@ -1211,7 +1226,7 @@ QStringList Scope::resolveVariables( const QStringList& values, QMake::AST* stop
     QMap<QString, QStringList> variables;
     for( QStringList::iterator it = result.begin(); it != result.end(); ++it )
     {
-        QRegExp re("\\$\\$([^{}\\) /]*)( |\\)|/|$)");
+        QRegExp re("\\$\\$([^{}\\) /]*)( |\\\\)|/|$)");
         int pos = 0;
         while( pos >= 0 )
         {
@@ -1235,6 +1250,23 @@ QStringList Scope::resolveVariables( const QStringList& values, QMake::AST* stop
                 pos += re.matchedLength();
             }
         }
+        re = QRegExp("\\$\\$\\(([^\\)\\}]*)\\)");
+        pos = 0;
+        QMap<QString, QString> envvars;
+        while( pos >= 0 )
+        {
+            pos = re.search( (*it), pos );
+            if( pos > -1 )
+            {
+                if( !envvars.contains( re.cap(1) ) && ::getenv( re.cap(1).local8Bit() ) != 0 )
+                    envvars[re.cap(1)] = QString::fromLocal8Bit(::getenv( re.cap(1).local8Bit() ) );
+                pos += re.matchedLength();
+            }
+        }
+        for( QMap<QString, QString>::const_iterator it2 = envvars.begin(); it2 != envvars.end(); ++it2 )
+        {
+            (*it).replace("$$("+it2.key()+")", it2.data() );
+        }
         for( QMap<QString, QStringList>::const_iterator it2 = variables.begin(); it2 != variables.end(); ++it2 )
         {
             for( QStringList::const_iterator it3 = it2.data().begin(); it3 != it2.data().end(); ++it3 )
@@ -1446,8 +1478,8 @@ QString Scope::findCustomVarForPath( const QString& path )
     QMap<unsigned int, QMake::AssignmentAST*>::const_iterator it = m_customVariables.begin();
     for( ; it != m_customVariables.end(); ++it )
     {
-        kdDebug(9024) << "Checking " << path << " against " << removeWhiteSpace(it.data()->values) << endl;
-        if( !it.data()->values.isEmpty() && removeWhiteSpace(it.data()->values).front() == path )
+        kdDebug(9024) << "Checking " << path << " against " << cleanStringList(it.data()->values) << endl;
+        if( !it.data()->values.isEmpty() && cleanStringList(it.data()->values).front() == path )
         {
             return it.data()->scopedID;
         }
@@ -1471,6 +1503,46 @@ void Scope::loadDefaultOpts()
     }
 }
 
+QString Scope::getLineEndingString() const
+{
+
+    if( scopeType() == ProjectScope )
+    {
+        switch( m_root->lineEnding() )
+        {
+            case QMake::ProjectAST::Windows:
+                return QString("\r\n");
+                break;
+            case QMake::ProjectAST::MacOS:
+                return QString("\r");
+                break;
+            case QMake::ProjectAST::Unix:
+                return QString("\n");
+                break;
+        }
+    }else if( m_parent )
+    {
+        return m_parent->getLineEndingString();
+    }
+    return "\n";
+}
+
+QString Scope::replaceWs(QString s)
+{
+    return s.replace( getLineEndingString(), "%nl").replace("\t", "%tab").replace(" ", "%spc");
+}
+
+bool Scope::containsContinue(const QString& s ) const
+{
+    return( s.find( QRegExp( "\\\\\\s*"+getLineEndingString() ) ) != -1
+            || s.find( QRegExp( "\\\\\\s*#" ) ) != -1 );
+}
+
+bool Scope::isComment( const QString& s) const
+{
+    return s.startsWith("#");
+}
+
 #ifdef DEBUG
 void Scope::printTree()
 {
