@@ -145,7 +145,7 @@ public:
     /* returns wether this is an enabled subproject or a disabled one */
     bool isEnabled() { return m_isEnabled; }
 
-    static QStringList removeWhiteSpace(const QStringList& list);
+    QStringList cleanStringList(const QStringList& list) const;
 
     /* Reload a project scope */
     void reloadProject();
@@ -238,6 +238,10 @@ private:
     QStringList variableValues( const QString& variable, QMake::AST* ) const;
     QString resolveVariables( const QString& , QMake::AST* ) const;
 
+    // This function determines the currently used String for fileending, it can be \n, \r or \r\n
+    QString getLineEndingString() const;
+    bool isComment( const QString& ) const;
+    bool containsContinue( const QString& ) const;
     void allFiles( const QString&, std::set<QString>& );
 
     void loadDefaultOpts();
@@ -249,6 +253,8 @@ private:
     Scope* m_parent;
     unsigned int m_maxCustomVarNum;
 
+    QString replaceWs(QString);
+
     // All different subscopes of this scope, the key is the "position" at which the scope starts
     QMap<QString, Scope*> m_subProjects;
 
@@ -287,10 +293,10 @@ private:
 
         virtual void processInclude( QMake::IncludeAST* a);
 
+        QString replaceWs(QString);
 
     private:
         QString getIndent();
-        QString replaceWs(QString);
         int indent;
 
     };
