@@ -70,7 +70,8 @@ TrollProjectPart::TrollProjectPart(QObject *parent, const char *name, const QStr
 
     setXMLFile("kdevtrollproject.rc");
 
-    m_executeAfterBuild = false;
+    m_executeProjectAfterBuild = false;
+    m_executeTargetAfterBuild = false;
 
     m_dirWatch = new KDirWatch(this);
 
@@ -113,6 +114,14 @@ TrollProjectPart::TrollProjectPart(QObject *parent, const char *name, const QStr
                               "Environment variables and make arguments can be specified "
                               "in the project settings dialog, <b>Make Options</b> tab."));
 
+    action = new KAction( i18n("&Install Project"),"install" , 0,
+                          m_widget, SLOT(slotInstallProject()),
+                          actionCollection(),"build_install_project"  );
+    action->setToolTip(i18n("Install project"));
+    action->setWhatsThis(i18n("<b>Install project</b><p>Runs <b>make install</b> from the project directory.<br>"
+                              "Environment variables and make arguments can be specified "
+                              "in the project settings dialog, <b>Make Options</b> tab."));
+
     action = new KAction( i18n("&Clean Project"), 0,
                           m_widget, SLOT(slotCleanProject()),
                           actionCollection(), "build_clean_project" );
@@ -153,6 +162,15 @@ TrollProjectPart::TrollProjectPart(QObject *parent, const char *name, const QStr
                               "Environment variables and make arguments can be specified "
                               "in the project settings dialog, <b>Make Options</b> tab."));
 
+    action = new KAction( i18n("&Install Subproject"), "install", 0,
+                          m_widget, SLOT(slotInstallTarget()),
+                          actionCollection(),"build_install_target"  );
+    action->setToolTip(i18n("Install subproject"));
+    action->setWhatsThis(i18n("<b>Install subproject</b><p>Runs <b>make install</b> from the current subproject directory. "
+                              "Current subproject is a subproject selected in <b>QMake manager</b> 'overview' window.<br>"
+                              "Environment variables and make arguments can be specified "
+                              "in the project settings dialog, <b>Make Options</b> tab."));
+
     action = new KAction( i18n("&Clean Subproject"), 0,
                           m_widget, SLOT(slotCleanTarget()),
                           actionCollection(), "build_clean_target" );
@@ -237,7 +255,7 @@ QString TrollProjectPart::makeEnvironment()
 
     if( !hasQtDir && !isQt4Project() && !DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "").isEmpty() )
     {
-         environstr += QString( "QTDIR=" ) + EnvVarTools::quote( DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "") ) + QString( " " );
+         environstr += QString( "QTDIR=" ) + EnvVarTools::quote( DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/root", "") ) + QString( " PATH=$QTDIR/bin:$PATH " );
     }
 
     return environstr;
@@ -417,7 +435,7 @@ void TrollProjectPart::slotBuildAndExecuteProject()
 {
     partController()->saveAllFiles();
     if (isDirty()) {
-        m_executeAfterBuild = true;
+        m_executeProjectAfterBuild = true;
         m_widget->slotBuildProject();
     } else
         m_widget->slotExecuteProject();
@@ -427,7 +445,7 @@ void TrollProjectPart::slotBuildAndExecuteTarget()
 {
     partController()->saveAllFiles();
     if (isDirty()) {
-        m_executeAfterBuild = true;
+        m_executeTargetAfterBuild = true;
         m_widget->slotBuildTarget();
     } else
         m_widget->slotExecuteTarget();
@@ -581,16 +599,15 @@ void TrollProjectPart::addFile(const QString &fileName)
 void TrollProjectPart::addFiles ( const QStringList &fileList )
 {
     QStringList files = fileList;
-//     for (QStringList::iterator it = files.begin(); it != files.end(); ++it)
-//     {
-// //        if (!(*it).contains(projectDirectory()))
-//       kdDebug(9024) << "Checking if isProjFile:" << (*it) << "?" << isProjectFile(projectDirectory() + QString( QChar( QDir::separator() ) ) + (*it)) << "|" << projectDirectory() << endl;
-//         if (!isProjectFile(projectDirectory() + QString( QChar( QDir::separator() ) ) + (*it)))
-//             *it = projectDirectory() + QString( QChar( QDir::separator() ) ) + (*it);
-//     }
+    for (QStringList::iterator it = files.begin(); it != files.end(); ++it)
+    {
+        if( !QFileInfo( *it ).isRelative() )
+        {
+            *it = URLUtil::relativePathToFile( projectDirectory(), *it );
+        }
+    }
     m_widget->addFiles(files);
 
-//	emit addedFilesToProject ( files );
 }
 
 void TrollProjectPart::removeFile(const QString & /* fileName */)
@@ -678,7 +695,7 @@ void TrollProjectPart::startQMakeCommand(const QString &dir)
     	cmdline = "tmake ";
     }else
     {
-      cmdline = DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/qmake", "")+" ";
+        cmdline = DomUtil::readEntry(*projectDom(), "/kdevcppsupport/qt/qmake", "")+" ";
     }
 
     //QString cmdline = QString::fromLatin1( isTMakeProject() ? "tmake " : "qmake " );
@@ -724,10 +741,16 @@ void TrollProjectPart::slotCommandFinished( const QString& command )
 
     emit projectCompiled();
 
-    if( m_executeAfterBuild ){
+    if( m_executeProjectAfterBuild )
+    {
         m_widget->slotExecuteProject();
-        m_executeAfterBuild = false;
+        m_executeProjectAfterBuild = false;
+    }else if( m_executeTargetAfterBuild )
+        {
+        m_widget->slotExecuteTarget();
+        m_executeTargetAfterBuild = false;
     }
+
 }
 
 bool TrollProjectPart::isDirty()
