@@ -50,7 +50,7 @@ protected:
 
     virtual QString projectDirectory() const;
     virtual QString projectName() const;
-    virtual QString mainProgram(bool relative = false) const;
+    virtual QString mainProgram() const;
     virtual QString activeDirectory() const;
     virtual QStringList allFiles() const;
     virtual void addFile(const QString &fileName);
@@ -59,6 +59,7 @@ protected:
     virtual void removeFiles ( const QStringList &fileList );
     virtual QString buildDirectory() const;
     virtual QString runDirectory() const;
+    virtual QString debugArguments() const;
     virtual QString runArguments() const;
     virtual DomUtil::PairList runEnvironmentVars() const;
 
@@ -89,7 +90,8 @@ private:
     bool m_tmakeProject;
 
     QMap<QString, QDateTime> m_timestamp;
-    bool m_executeAfterBuild;
+    bool m_executeProjectAfterBuild;
+    bool m_executeTargetAfterBuild;
     QString m_buildCommand;
 
     KDirWatch* m_dirWatch;
