@@ -214,7 +214,10 @@ DomUtil::PairList ScriptProjectPart::runEnvironmentVars() const
   */
 QString ScriptProjectPart::runDirectory() const
 {
-    return defaultRunDirectory("kdevscriptproject");
+    QString cwd = defaultRunDirectory("kdevscriptproject");
+    if (cwd.isEmpty())
+      cwd = buildDirectory();
+    return cwd;
 }
 
 
@@ -227,27 +230,32 @@ QString ScriptProjectPart::runDirectory() const
   *   if run/directoryradio == custom or relative == false
   *        The absolute path to executable
   */
-QString ScriptProjectPart::mainProgram(bool relative) const
+QString ScriptProjectPart::mainProgram() const
 {
-    QDomDocument &dom = *projectDom();
+    QDomDocument * dom = projectDom();
 
-    QString directoryRadioString = DomUtil::readEntry(dom, "/kdevscriptproject/run/directoryradio");
-    QString DomMainProgram = DomUtil::readEntry(dom, "/kdevscriptproject/run/mainprogram");
+    if ( !dom ) return QString();
 
-    if ( directoryRadioString == "custom" )
-        return DomMainProgram;
+    QString DomMainProgram = DomUtil::readEntry( *dom, "/kdevscriptproject/run/mainprogram");
 
-    if ( relative == false )
-        return buildDirectory() + "/" + DomMainProgram;
+    if ( DomMainProgram.isEmpty() ) return QString();
 
-    if ( directoryRadioString == "executable" ) {
-        int pos = DomMainProgram.findRev('/');
-        if (pos != -1)
-            return DomMainProgram.mid(pos+1);
+    if ( DomMainProgram.startsWith("/") )   // assume absolute path
+    {
         return DomMainProgram;
     }
-    else
-        return DomMainProgram;
+    else // assume project relative path
+    {
+        return projectDirectory() + "/" + DomMainProgram;
+    }
+
+    return QString();
+}
+
+/** Retuns a QString with the debug command line arguments */
+QString ScriptProjectPart::debugArguments() const
+{
+    return DomUtil::readEntry(*projectDom(), "/kdevscriptproject/run/globaldebugarguments");
 }
 
 
