@@ -38,7 +38,7 @@ protected:
 
     virtual QString projectDirectory() const;
     virtual QString projectName() const;
-    virtual QString mainProgram(bool relative = false) const;
+    virtual QString mainProgram() const;
     virtual QString activeDirectory() const;
     virtual QStringList allFiles() const;
     virtual void addFile(const QString &fileName);
@@ -47,6 +47,7 @@ protected:
     virtual void removeFiles ( const QStringList& fileList );
     virtual QString buildDirectory() const;
     virtual QString runDirectory() const;
+    virtual QString debugArguments() const;
     virtual QString runArguments() const;
     virtual DomUtil::PairList runEnvironmentVars() const;
 
