@@ -1,27 +1,27 @@
 
-#ifndef _PLUGIN_$APPNAMEUC$_H_
-#define _PLUGIN_$APPNAMEUC$_H_
+#ifndef _PLUGIN_%{APPNAMEUC}_H_
+#define _PLUGIN_%{APPNAMEUC}_H_
 
 #include <kparts/plugin.h>
 #include <kparts/factory.h>
 
-class Plugin$APPNAME$ : public KParts::Plugin
+class Plugin%{APPNAME} : public KParts::Plugin
 {
   Q_OBJECT
 public:
-  Plugin$APPNAME$( QObject* parent = 0, const char* name = 0 );
-  virtual ~Plugin$APPNAME$();
+  Plugin%{APPNAME}( QObject* parent = 0, const char* name = 0 );
+  virtual ~Plugin%{APPNAME}();
 
 public slots:
   void slotAction();
 };
 
-class $APPNAME$Factory : public KParts::Factory
+class %{APPNAME}Factory : public KLibFactory
 {
   Q_OBJECT
 public:
-  $APPNAME$Factory();
-  virtual ~$APPNAME$Factory();
+  %{APPNAME}Factory();
+  virtual ~%{APPNAME}Factory();
 
   virtual QObject* createObject( QObject* parent = 0, const char* pname = 0, const char* name = "QObject", const QStringList &args = QStringList() );
 
@@ -31,4 +31,4 @@ private:
   static KInstance* s_instance;
 };
 
-#endif // _PLUGIN_$APPNAMEUC$_H_
+#endif // _PLUGIN_%{APPNAMEUC}_H_
