@@ -195,11 +195,11 @@ OptimizationTab::OptimizationTab( GccOptionsPlugin::Type type, QWidget *parent,
 	                                        "doing arithmetic on them</qt>" ),
 	                  "-fno-force-addr" );
 	new FlagListItem( optBox,
-	                  "-omit-frame-pointer", i18n( "<qt>Do not keep the frame pointer in a register for functions that "
+	                  "-fomit-frame-pointer", i18n( "<qt>Do not keep the frame pointer in a register for functions that "
 	                                               "do not need one</qt>" ),
 	                  "-fno-omit-frame-pointer" );
 	new FlagListItem( optBox,
-	                  "-no-inline", i18n( "<qt>Ignore the <i>inline</i> keyword</qt>" ),
+	                  "-fno-inline", i18n( "<qt>Ignore the <i>inline</i> keyword</qt>" ),
 	                  "-finline" );
 
 	if ( type == GccOptionsPlugin::GPP )
@@ -346,6 +346,11 @@ Warnings1Tab::Warnings1Tab( GccOptionsPlugin::Type type, QWidget *parent, const
 	                                    "to make sure that the arguments supplied have types appropriate\n"
 	                                    "to the format string specified, and that the conversions specified\n"
 	                                    "in the format string make sense</qt>" ) );
+	new FlagListItem( wallBox,
+	                  "-Wformat=2", i18n( "<qt>Enable -Wformat plus format checks not \n"
+				              "included in -Wformat. Currently equivalent to \n"
+					      "`-Wformat -Wformat-nonliteral -Wformat-security \n"
+					      "-Wformat-y2k'.</qt>" ) );
 	new FlagListItem( wallBox,
 	                  "-Wimplicit-int", i18n( "<qt>Warn when a declaration does not specify a type</qt>" ) );
 	new FlagListItem( wallBox,
