@@ -21,6 +21,9 @@
 #include <kdevcore.h>
 #include <kdevlanguagesupport.h>
 
+#include <qthread.h>
+#include <qmutex.h>
+#include <qtimer.h>
 #include <kdialogbase.h>
 #include <qguardedptr.h>
 #include <qstring.h>
@@ -29,8 +32,42 @@
 #include <qdir.h>
 #include <qprogressbar.h>
 #include <kdebug.h>
+#include <ext/hash_map>
 #include "driver.h"
 
+
+///A class that helps detecting what exactly makes the UI block. To use it, just place a breakpoint on UIBlockTester::lockup() and inspect the execution-position of the main thread
+class UIBlockTester : public QObject {
+	Q_OBJECT
+    class UIBlockTesterThread : public QThread {
+    public:
+      UIBlockTesterThread( UIBlockTester& parent );
+      void run();
+      
+    private:
+      UIBlockTester& m_parent;
+    };
+  friend class UIBlockTesterThread;
+public:
+    
+  ///@param milliseconds when the ui locks for .. milliseconds, lockup() is called
+  UIBlockTester( uint milliseconds );
+  ~UIBlockTester();
+	
+private slots:
+  void timer();
+	
+protected:
+  virtual void lockup();
+
+private:
+    UIBlockTesterThread m_thread;
+	QDateTime m_lastTime;
+	QMutex m_timeMutex;
+	QTimer * m_timer;
+	uint m_msecs;
+};
+
 class Context;
 class CppCodeCompletion;
 class CppCodeCompletionConfig;
@@ -52,7 +89,6 @@ class KPopupMenu;
 class BackgroundParserConfig;
 class KAction;
 
-
 namespace KParts
 {
 	class Part;
@@ -66,6 +102,55 @@ namespace KTextEditor
 	class ViewCursorInterface;
 }
 
+
+class SynchronizedFileSet
+{
+public:
+    typedef __gnu_cxx::hash_set< HashedString > SetType;
+    SynchronizedFileSet()
+	{}
+	
+	bool isEmpty() const
+	{
+		QMutexLocker locker( &m_mutex );
+		return m_fileSet.empty();
+	}
+	
+	uint count() const
+	{
+		QMutexLocker locker( &m_mutex );
+		return m_fileSet.size();
+	}
+	
+	void clear()
+	{
+		QMutexLocker locker( &m_mutex );
+		m_fileSet.clear();
+	}
+
+    void setFiles( const SetType& files ) {
+		QMutexLocker locker( &m_mutex );
+        m_fileSet = files;
+    }
+	
+	void insert( const HashedString& str )
+	{
+        HashedString s( QString::fromUtf8(str.str().utf8()) );
+		QMutexLocker locker( &m_mutex );
+          
+		m_fileSet.insert( s );
+	}
+
+    bool contains( const HashedString& str ) const {
+		QMutexLocker locker( &m_mutex );
+        return m_fileSet.find( str ) != m_fileSet.end();
+    }
+
+private:
+	mutable QMutex m_mutex;
+	SetType m_fileSet;
+};
+
 class CppSupportPart : public KDevLanguageSupport
 {
 	Q_OBJECT
@@ -152,6 +237,9 @@ public:
 	bool isHeader( const QString& fileName ) const;
 	bool isSource( const QString& fileName ) const;
 
+    //uses the old simple algorithm to find the header
+    QString findHeaderSimple( const QString &header );
+  
 	virtual KDevDesignerIntegration *designer( KInterfaceDesigner::DesignerType type );
 
 	void setTyping( bool typing );
@@ -176,8 +264,15 @@ public:
 	void createAccessMethods( ClassDom theClass, VariableDom theVariable );
 
     bool isQueued( const QString& file ) const;
-    bool switchHeaderImpl( const QString& file, int line, int col, QString candidate = QString::null, bool scrollOnly = false );
+    bool switchHeaderImpl( const QString& file, int line, int col, bool scrollOnly = false );
 
+    const Driver* driver() const;
+
+    Driver* driver();
+
+    ///thread-safe, returns the thread-safe set of all files that do not need to be parsed when being included, either because they are part of the project and parsed anyway, or because they are already in the code-repository
+    const SynchronizedFileSet& safeFileSet() const;
+    SynchronizedFileSet& safeFileSet();
 signals:
 	void fileParsed( const QString& fileName );
     ///Emitted whenever a file was parsed, but the code-model could be updated(the file in the code-model did not have to be replaced)
@@ -215,7 +310,6 @@ private slots:
 	void slotNavigate();
 	void slotNewClass();
 	void slotSwitchHeader( bool scrollOnly = false );
-	void slotGotoIncludeFile();
 	void slotCompleteText();
 	void slotMakeMember();
 	void slotExtractInterface();
@@ -295,6 +389,15 @@ private:
 
     QString sourceOrHeaderCandidate( const KURL &url = KURL() );
 
+	FunctionDom findFunction( const FunctionDom& def );
+	FunctionDom findFunctionInNamespace( const NamespaceDom& ns, const FunctionDom& def, const std::set<NamespaceImportModel>& nsImports,
+	                                     const QString& candidateFile, int scopeIndex, FunctionDom& bestMatch );
+	FunctionDom findFunctionInClass( const ClassDom& cs, const FunctionDom& def, const std::set<NamespaceImportModel>& nsImports,
+	                                 const QString& candidateFile, int scopeIndex, FunctionDom& bestMatch );
+	FunctionDom findFunctionDefinition( const FunctionDom& decl );
+
+	void jumpToCodeModelItem( const ItemDom& item, bool scrollOnly );
+
 	QStringList modifiedFileList();
 	QString findSourceFile();
 	int pcsVersion();
@@ -302,7 +405,6 @@ private:
 
 	void saveProjectSourceInfo();
 	QStringList reorder( const QStringList& list );
-	static QString findHeader( const QStringList&list, const QString& header );
 
 	CppCodeCompletion* m_pCompletion;
 	CppCodeCompletionConfig* m_pCompletionConfig;
@@ -321,6 +423,7 @@ private:
 	ClassDom m_curClass;
 	QGuardedPtr< ProblemReporter > m_problemReporter;
 	BackgroundParser* m_backgroundParser;
+    UIBlockTester* m_lockupTester;
 
 	KTextEditor::Document* m_activeDocument;
 	KTextEditor::View* m_activeView;
@@ -356,6 +459,7 @@ private:
 	QTimer* m_saveMemoryTimer;
 	QTimer * m_textChangedTimer;
 	QTimer * m_cursorMovedTimer;
+    QTimer* m_buildSafeFileSetTimer;
     
     class ParseEmitWaiting {
     public:
@@ -504,8 +608,10 @@ private:
 
 private slots:
 	void parseEmit( ParseEmitWaiting::Processed files );
+    void  buildSafeFileSet();
 private:
-	
+
+    SynchronizedFileSet m_safeProjectFiles;
 	BackgroundParserConfig * m_backgroundParserConfig;
 	
 	static QStringList m_sourceMimeTypes;
@@ -517,6 +623,11 @@ private:
 	friend class KDevCppSupportIface;
 	friend class CppDriver;
 
+	// we need something to plug actions that are not in any menu 
+	// into in order for their shortcuts to work
+	QWidget m_DummyActionWidget;
+
+    void addToRepository( ParsedFilePointer );
 	void emitSynchronousParseReady( const QString& file, ParsedFilePointer unit );
 
 	struct JobData
