@@ -53,6 +53,7 @@ void QtBuildConfig::init( )
 	m_root = DomUtil::readEntry( *m_dom, m_configRoot + "/root", "" );
     m_qmakePath = DomUtil::readEntry(*m_dom, m_configRoot + "/qmake", "");
     m_designerPath = DomUtil::readEntry(*m_dom, m_configRoot + "/designer", "");
+    m_designerPluginPaths = DomUtil::readListEntry(*m_dom, m_configRoot + "/designerpluginpaths", "path" );
 
     if( m_root.isEmpty() || !isValidQtDir( m_root ) )
     {
@@ -60,13 +61,18 @@ void QtBuildConfig::init( )
     }
     if( m_qmakePath.isEmpty() || !isExecutable( m_qmakePath ) )
     {
-        m_qmakePath = findExecutable( "qmake" );
+        m_qmakePath = findExecutable( "qmake-qt"+ QString::number( m_version ) );
+        if( m_qmakePath.isEmpty() || !isExecutable( m_qmakePath ) )
+            m_qmakePath = findExecutable( "qmake" );
     }
     if( m_designerPath.isEmpty() || !isExecutable( m_designerPath ) )
     {
-        m_designerPath = findExecutable( "designer" );
+        m_designerPath = findExecutable( "designer-qt"+QString::number( m_version ) );
+        if( m_designerPath.isEmpty() || !isExecutable( m_designerPath ) )
+            m_designerPath = findExecutable( "designer" );
     }
 
+
 	m_designerIntegration = DomUtil::readEntry( *m_dom, m_configRoot + "/designerintegration" );
 	if( m_designerIntegration.isEmpty() )
 	{
@@ -161,6 +167,7 @@ void QtBuildConfig::store( )
 	DomUtil::writeEntry( *m_dom, m_configRoot + "/designerintegration", m_designerIntegration );
     DomUtil::writeEntry(*m_dom, m_configRoot + "/qmake", m_qmakePath );
     DomUtil::writeEntry(*m_dom, m_configRoot + "/designer", m_designerPath );
+    DomUtil::writeListEntry(*m_dom, m_configRoot + "/designerpluginpaths", "path",  m_designerPluginPaths );
 
 	emit stored();
 }
@@ -190,6 +197,11 @@ void QtBuildConfig::setQMakePath( const QString& path )
     m_qmakePath = path;
 }
 
+void QtBuildConfig::setDesignerPluginPaths( const QStringList& pfx )
+{
+    m_designerPluginPaths = pfx;
+}
+
 void QtBuildConfig::setDesignerPath( const QString& path )
 {
     m_designerPath = path;
