@@ -15,6 +15,41 @@
 #include "simpletype.h"
 #include "safetycounter.h"
 #include "simpletypefunction.h"
+#include <klocale.h>
+
+QMap<QString, QString> BuiltinTypes::m_types;
+BuiltinTypes builtin; //Needed so BuiltinTypes::BuiltinTypes is called and the types are initialized
+
+BuiltinTypes::BuiltinTypes() {
+  m_types[ "void" ] = i18n( "typeless" );
+  m_types[ "bool" ] = i18n("boolean value, 1 byte, ( \"true\" or \"false\" )");
+  m_types["char" ] = i18n("signed/unsigned character, 1 byte");
+  m_types["signed char" ] =  i18n("signed character, 1 byte, ranged -128 to 127");
+  m_types["unsigned char"] = i18n("unsigned character, 1 byte, ranged 0 to 255");
+  m_types["wchar_t"] = i18n("wide character, 2 bytes, ranged 0 to 65.535");
+  m_types["long"] = m_types["long int"] = m_types["int"] = m_types["signed int"] = i18n("signed interger, 4 bytes, ranged -2.147.483.648 to 2.147.483.647");
+  m_types["unsigned"] = m_types["unsigned int"] = i18n("unsigned integer, 4 bytes, ranged 0 to 4.294.967.295");
+  m_types["short"] = m_types["short int"] = i18n("short integer, 2 bytes, ranged -32.768 to 32.768");
+  m_types["unsigned short int"] = i18n("unsigned short integer, 2 bytes, ranged 0 to 65.535");
+  m_types["float"] = i18n("floating point value, 4 bytes, ranged ca. -3,4E+38 to 3.4E+38");
+  m_types["double"] = i18n("double floating point value, 8 bytes, ranged ca. -1.8E+308 to 1.8E+308");
+  m_types["long double"] = i18n("double long floating point value, 10 bytes, ranged ca. -3.4E+4932 to 3.4E+4932");
+  m_types["size_t"] = i18n("unsigned integer, byte-count depending on operating-system" );
+   
+}
+
+bool BuiltinTypes::isBuiltin( const TypeDesc& desc ) {
+  return m_types.find( desc.name() ) != m_types.end();
+}
+
+QString BuiltinTypes::comment( const TypeDesc& desc ) {
+  QMap<QString, QString>::iterator it = m_types.find( desc.name() );
+  if( it != m_types.end() ) {
+    return *it;
+  } else {
+    return QString::null;
+  }
+}
 
 extern SafetyCounter safetyCounter;
 
@@ -170,16 +205,36 @@ SimpleType::SimpleType( Tag tag ) : m_resolved(true) {
 //
 //SimpleTypeImpl implementation
 
+QValueList<LocateResult> SimpleTypeImpl::getBases() {
+QValueList<LocateResult> ret;
+  QStringList bases = getBaseStrings();
+  for( QStringList::const_iterator it = bases.begin(); it != bases.end(); ++it ) {
+    TypeDesc d( *it );
+    d.setIncludeFiles( m_findIncludeFiles );
+    LocateResult res = locateDecType( d, LocateBase );
+    //if( res )
+      ret << res;
+  }
+  return ret;
+}
+
+void SimpleTypeImpl::setFindIncludeFiles( const IncludeFiles& files ) {
+  m_findIncludeFiles = files;
+}
+
+IncludeFiles SimpleTypeImpl::getFindIncludeFiles() {
+  return m_findIncludeFiles;
+}
+
 /**
-Searches for a member called "name", considering all types selected through "typ"
-TODO: cache this too */
+Searches for a member called "name", considering all types selected through "typ"*/
 SimpleTypeImpl::TypeOfResult SimpleTypeImpl::typeOf( const TypeDesc& name, MemberInfo::MemberType typ ) {
   Debug d( "#to#" );
   if ( !d ) {
     ifVerbose( dbg() << "stopping typeOf-evaluation because the recursion-depth is too high" << endl );
     return TypeOfResult( LocateResult( TypeDesc( "CompletionError::too_much_recursion" ) ) );
   }
-  ifVerbose( dbg() << "\"" << str() << "\"------------>: searching for type of member \"" << name << "\"" << endl );
+  ifVerbose( dbg() << "\"" << str() << "\"------------>: searching for type of member \"" << name.fullNameChain() << "\"" << endl );
 
   TypeDesc td = resolveTemplateParams( name );
 
@@ -188,39 +243,42 @@ SimpleTypeImpl::TypeOfResult SimpleTypeImpl::typeOf( const TypeDesc& name, Membe
   if ( mem ) {
     mem.type = resolveTemplateParams( mem.type );
 
-    ifVerbose( dbg() << "\"" << str() << "\": found member " << name << ", type: " << mem.type->fullNameChain() << endl );
+    ifVerbose( dbg() << "\"" << str() << "\": found member " << name.fullNameChain() << ", type: " << mem.type->fullNameChain() << endl );
     if ( mem.memberType == MemberInfo::Function ) {
       ///For functions, find all functions with the same name, so that overloaded functions can be identified correctly
       TypePointer ret = mem.build();
       if ( ret && ret->asFunction() ) {
-        ///Search all bases and append all functions with the same name to it.
-        QValueList<LocateResult> bases = getBases();
-        for ( QValueList<LocateResult>::iterator it = bases.begin(); it != bases.end(); ++it ) {
-          if( !safetyCounter ) break;
-          if ( ( *it ) ->resolved() ) {
-            TypeOfResult rt = ( *it ) ->resolved() ->typeOf( name );
-            if ( rt->resolved() )
-              ret->asFunction() ->appendNextFunction( SimpleType( rt->resolved() ) );
-          }
-        }
         return TypeOfResult( LocateResult( ret->desc() ) );
       } else {
         ifVerbose( dbg() << "error, using old function-type-evaluation" << endl );
-        return TypeOfResult( locateDecType( mem.type ), mem.decl );
+
+        TypeDesc d( mem.type );
+        if( m_findIncludeFiles.size() != 0 )
+          d.setIncludeFiles( m_findIncludeFiles );
+        else
+          d.setIncludeFiles( name.includeFiles() );
+
+        return TypeOfResult( locateDecType( d ), mem.decl );
       }
     } else if ( mem.memberType == MemberInfo::Variable ) {
-      return TypeOfResult( locateDecType( mem.type ), mem.decl );
+        TypeDesc d( mem.type );
+        if( m_findIncludeFiles.size() != 0 )
+          d.setIncludeFiles( m_findIncludeFiles );
+        else
+          d.setIncludeFiles( name.includeFiles() );
+      
+      return TypeOfResult( locateDecType( d ), mem.decl );
     } else {
-      ifVerbose( dbg() << "while searching for the type of \"" << name << "\" in \"" << str() << "\": member has wrong type: \"" << mem.memberTypeToString() << "\"" << endl );
+      ifVerbose( dbg() << "while searching for the type of \"" << name.fullNameChain() << "\" in \"" << str() << "\": member has wrong type: \"" << mem.memberTypeToString() << "\"" << endl );
       return TypeOfResult();
     }
   }
 
   TypeOfResult ret = searchBases( td );
   if ( !ret ) {
-    ifVerbose( dbg() << "\"" << str() << "\"------------>: failed to resolve the type of member \"" << name << "\"" << endl );
+    ifVerbose( dbg() << "\"" << str() << "\"------------>: failed to resolve the type of member \"" << name.fullNameChain() << "\"" << endl );
   } else {
-    ifVerbose( dbg() << "\"" << str() << "\"------------>: successfully resolved the type of the member \"" << name << "\"" << endl );
+    ifVerbose( dbg() << "\"" << str() << "\"------------>: successfully resolved the type of the member \"" << name.fullNameChain() << "\"" << endl );
   }
   return ret;
 }
@@ -278,8 +336,8 @@ LocateResult SimpleTypeImpl::applyOperator( Operator op , QValueList<LocateResul
     case ArrowOp:
     /** Dereference one more because the type must be a pointer */
     ret = getFunctionReturnType( "operator ->", params );
-    if ( ret->pointerDepth() ) {
-      ret->setPointerDepth( ret->pointerDepth() - 1 );
+    if ( ret->totalPointerDepth() ) {
+      ret->setTotalPointerDepth( ret->totalPointerDepth() - 1 );
     } else {
       ifVerbose( dbg() << "\"" << str() << "\": " << " \"operator ->\" returns a type with the wrong pointer-depth" << endl );
     }
@@ -311,7 +369,7 @@ TypeDesc SimpleTypeImpl::replaceTemplateParams( TypeDesc desc, TemplateParamInfo
         ret = t.def;
 
       if ( ret.name() != desc.name() )
-        ret.setPointerDepth( ret.pointerDepth() + desc.pointerDepth() );
+        ret.setTotalPointerDepth( ret.totalPointerDepth() + desc.totalPointerDepth() );
     }
   } else {
     TypeDesc::TemplateParams& params = ret.templateParams();
@@ -337,7 +395,10 @@ TypeDesc SimpleTypeImpl::resolveTemplateParams( LocateResult desc, LocateMode mo
     TypeDesc::TemplateParams & params = ret->templateParams();
     for ( TypeDesc::TemplateParams::iterator it = params.begin(); it != params.end(); ++it ) {
       if ( !( *it ) ->resolved() && !( *it ) ->hasFlag( ResolutionTried ) ) {
-        *it = locateDecType( **it, mode );
+        TypeDesc d( **it );
+        if( d.includeFiles().size() == 0 )
+          d.setIncludeFiles( this->getFindIncludeFiles() );
+        *it = locateDecType( d, mode );
         ( *it ) ->setFlag( ResolutionTried );
       }
     }
@@ -393,10 +454,10 @@ class TemplateParamMatch {
 
 					//Check if the decoration of the specialization matches the decoration of the arguments, if not we have a mismatch.
 
-					if( specialization.pointerDepth() > params->pointerDepth() ) {
+					if( specialization.totalPointerDepth() > params->totalPointerDepth() ) {
 						return false; //The decoration does not match the given argument
 					} else {
-						depth += specialization.pointerDepth();
+						depth += specialization.totalPointerDepth();
 						if( depth > m_maxDepth ) m_maxDepth = depth;
 					}
 					
@@ -408,7 +469,7 @@ class TemplateParamMatch {
 						val = params;  //No more parameters have to be checked, so take the value and return later
 					}
 
-					val->setPointerDepth( val->pointerDepth() - specialization.pointerDepth() );
+					val->setTotalPointerDepth( val->totalPointerDepth() - specialization.totalPointerDepth() );
 					
 					t.value = val;
 					
@@ -502,7 +563,7 @@ void SimpleTypeImpl::chooseSpecialization( MemberInfo& member ) {
   if ( m_masterProxy )
     t = m_masterProxy;
 
-  QValueList<TypePointer> classes = t->getMemberClasses( type->desc().name() );
+  QValueList<TypePointer> classes = t->getMemberClasses( type->desc() );
 
   //Find the specialization that fits the given template-parameters the best
 
@@ -551,6 +612,9 @@ void SimpleTypeImpl::chooseSpecialization( MemberInfo& member ) {
 
 LocateResult SimpleTypeImpl::locateType( TypeDesc name , LocateMode mode , int dir , MemberInfo::MemberType typeMask ) {
   Debug d( "#lo#" );
+  if( BuiltinTypes::isBuiltin( name ) )
+    return name;
+
   if ( !name || !safetyCounter || !d ) {
     return desc();
   }
@@ -558,7 +622,7 @@ LocateResult SimpleTypeImpl::locateType( TypeDesc name , LocateMode mode , int d
     ifVerbose( dbg() << "stopping location because the recursion-depth is too high" << endl );
     return TypeDesc( "CompletionError::too_much_recursion" );
   }
-    ifVerbose( dbg() << "\(" << uint(this) << ")\"" << desc().fullName() << "\": locating type \"" << name.fullNameChain() << "\"" << endl );
+    ifVerbose( dbg() << "\(" << uint(this) << ")\"" << str() << "\": locating type \"" << name.fullNameChain() << "\"" << endl );
   if ( name.resolved() && !name.next() ) {
     ifVerbose( dbg() << "\"" << desc().fullName() << "\": type \"" << name.fullNameChain() << "\" is already resolved, returning stored instance" << endl );
     return name;
@@ -575,6 +639,19 @@ LocateResult SimpleTypeImpl::locateType( TypeDesc name , LocateMode mode , int d
        
        return ret;
      }*/
+  /*
+  //This optimization is now disabled, because it allows following a wrong path.
+  if( name.next() ) {
+    //This is an optimization for better use of the cache: Find the elements separately, so searches
+    //For elements that start with the same scope will be speeded up.
+    LocateResult r = locateType( name.firstType(), mode, dir, typeMask );
+    if( r && r->resolved() && r.locateMode().valid ) {
+      ifVerbose( dbg() << "splitting location" );
+      TypeDesc d( *name.next() );
+      d.setIncludeFiles( name.includeFiles() );
+      return r->resolved()->locateType( d, (LocateMode)r.locateMode().mode, r.locateMode().dir );
+    }
+   }*/
 
   LocateResult ret = name; ///In case the type cannot be located, this helps to find at least the best match
   //LocateResult ret;
@@ -594,7 +671,9 @@ LocateResult SimpleTypeImpl::locateType( TypeDesc name , LocateMode mode , int d
       SimpleType sub;
       if ( TypePointer t = mem.build() ) {
         sub = SimpleType( t );
+#ifdef PHYSICAL_IMPORT
         setSlaveParent( *sub );
+#endif
       } else {
         ///Should not happen..
         kdDebug( 9007 ) << "\"" << str() << "\": Warning: the nested-type " << name.name() << " was found, but has no build-info" << endl;
@@ -602,15 +681,21 @@ LocateResult SimpleTypeImpl::locateType( TypeDesc name , LocateMode mode , int d
       }
 
       TypeDesc rest;
+      LocateMode newMode = addFlag( mode, ExcludeTemplates );
+      int newDir = 1;
       if ( name.next() ) {
         ifVerbose( dbg() << "\"" << str() << "\": found nested type \"" << name.name() << "\", passing control to it\n" );
-        ret = sub->locateType( resolveTemplateParams( *name.next(), Normal ), addFlag( mode, ExcludeTemplates ), 1 ); ///since template-names cannot be referenced from outside, exclude them for the first cycle
+        ret = sub->locateType( resolveTemplateParams( *name.next(), Normal ), newMode, newDir ); ///since template-names cannot be referenced from outside, exclude them for the first cycle
         ret.increaseResolutionCount();
         if ( ret->resolved() )
           return ret.resetDepth();
       } else {
         ifVerbose( dbg() << "\"" << str() << "\": successfully located searched type \"" << name.fullNameChain() << "\"\n" );
         ret->setResolved( sub.get() );
+        ret->resolved()->setFindIncludeFiles( name.includeFiles() );
+        ret.locateMode().valid = true;
+        ret.locateMode().mode = (uint)newMode;
+        ret.locateMode().dir = newDir;
         return ret.resetDepth();
       }
       break;
@@ -877,7 +962,7 @@ void SimpleTypeImpl::setScope( const QStringList& scope ) {
   invalidateCache();
   m_scope = scope;
   if ( m_scope.count() == 1 && m_scope.front().isEmpty() ) {
-    kdDebug() << "bad scope set " << kdBacktrace() << endl;
+    //kdDebug() << "bad scope set " << kdBacktrace() << endl;
     m_scope = QStringList();
   }
 }
