@@ -366,8 +366,13 @@ void StoreWalker::parseFunctionDefinition( FunctionDefinitionAST* ast )
 	QString id = d->declaratorId() ->unqualifiedName() ->text().stripWhiteSpace();
 	
 	QStringList scope = scopeOfDeclarator( d, m_currentScope );
-	ClassDom c = findClassFromScope( scope );
-	if( c ){
+	ClassDom c; ///c should be nonzero if it is a function-definition for a function within another class
+	if( !m_currentClass.top() ) {
+		///It is not a local definition within a class, so search the scope so it can be corrected using imports
+		c = findClassFromScope( scope );
+	}
+	
+	if( c ) {
 		scope = c->scope();
 		scope << c->name();
 	}
@@ -406,7 +411,7 @@ void StoreWalker::parseFunctionDefinition( FunctionDefinitionAST* ast )
 		method->setVirtual( isVirtual );
 		
 		if ( m_currentClass.top() )
-			m_currentClass.top() ->addFunction( model_cast<FunctionDom>( method ) );
+			m_currentClass.top() ->addFunction( model_cast<FunctionDom>( method ) ); 
 		else
 			m_file->addFunction( model_cast<FunctionDom>( method ) );
 	}
@@ -464,6 +469,16 @@ void StoreWalker::checkTemplateDeclarator( TemplateModelItem* item ) {
 	}
 }
 
+int StoreWalker::mergeGroups( int g1, int g2 ) {
+	int ng = m_store->mergeGroups( g1, g2 );
+	for( QMap<QString, FileDom>::iterator it = m_overrides.begin(); it != m_overrides.end(); ++it ) {
+		int g =(*it)->groupId();
+		if( g == g1 || g == g2 )
+			(*it)->setGroupId( ng );
+	}
+	return ng;
+}
+
 void StoreWalker::parseClassSpecifier( ClassSpecifierAST* ast )
 {
 	int startLine, startColumn;
@@ -528,7 +543,7 @@ void StoreWalker::parseClassSpecifier( ClassSpecifierAST* ast )
 				///since we are creating a link between both files, put them into the same parsing-group
 				FileDom dm = embedderClass->file();
 				if( dm ) {
-					m_file->setGroupId( m_store->mergeGroups( dm->groupId(), m_file->groupId() ) );
+					m_file->setGroupId( mergeGroups( dm->groupId(), m_file->groupId() ) );
 				}else{
 					kdDebug() << "file " << embedderClass->fileName() << " missing in store \n";
 				}
@@ -682,13 +697,12 @@ void StoreWalker::parseDeclaration( GroupAST* funSpec, GroupAST* storageSpec,
 		kdDebug( 9007 ) << "skip declaration of " << QStringList(scopeOfDeclarator( d, QStringList() )).join("::") << "::" << id << endl;
 		return ;
 	}
-	
+
 	VariableDom attr = m_store->create<VariableModel>();
 	attr->setName( id );
 	attr->setFileName( m_fileName );
 	attr->setComment( comment() );
-	
-	
+		
 	if ( m_currentClass.top() )
 		m_currentClass.top() ->addVariable( attr );
 	else if ( m_currentNamespace.top() )
@@ -699,8 +713,9 @@ void StoreWalker::parseDeclaration( GroupAST* funSpec, GroupAST* storageSpec,
 	attr->setAccess( m_currentAccess );
 	
 	QString text = typeOfDeclaration( typeSpec, d );
-	if ( !text.isEmpty() )
-		attr->setType( text );
+  if ( !text.isEmpty() ) {
+        attr->setType( text );
+  }
 	
 	bool isFriend = false;
 	//bool isVirtual = false;
@@ -913,6 +928,10 @@ QString StoreWalker::typeOfDeclaration( TypeSpecifierAST* typeSpec, DeclaratorAS
 	{
 		text += it.current() ->text();
 	}
+
+    for( int a = 0; a < declarator->arrayDimensionList().count(); a++ )
+        text += "*";
+
 	
 	return text;
 }
@@ -958,6 +977,7 @@ QStringList StoreWalker::scopeOfName( NameAST* id, const QStringList& startScope
 }
 
 
+///@todo respect the imports that result from the headers etc.
 ClassDom StoreWalker::findClassFromScope( const QStringList& scope ) 
 {
 	QString scopeText = scope.join("::");
@@ -973,7 +993,7 @@ ClassDom StoreWalker::findClassFromScope( const QStringList& scope )
 		if( !m_imports.isEmpty() ) m_imports.back().first[ scopeText ] = c;
 		return c;
 	}
-	
+
 	if(!m_imports.isEmpty() && !m_imports.back().second.isEmpty()) {
 			///try the same using one of the imports(performance-wise this is not good, but simple)
 		
@@ -991,31 +1011,64 @@ ClassDom StoreWalker::findClassFromScope( const QStringList& scope )
 	return c;
 }
 
+ClassDom  findScopeInFile( const QStringList& scope, NamespaceModel* glob ) {
+		if( !glob ) return ClassDom();
+		
+		ClassModel* curr =  glob ;
+		
+		QStringList::const_iterator mit = scope.begin();
+		
+		while(curr->isNamespace() && mit != scope.end() && ((NamespaceModel*)curr)->hasNamespace( *mit )) {
+			curr = &(*( ((NamespaceModel*)curr)->namespaceByName( *mit ) ));
+			++mit;
+		}
+		
+		while((curr->isNamespace() || curr->isClass()) && mit != scope.end() && curr->hasClass( *mit )) {
+			ClassList cl = curr->classByName( *mit );
+			curr = &(**cl.begin() );
+			++mit;
+		}
+		
+		if(mit == scope.end()) {
+			return curr;
+		} else {
+			return ClassDom(0);
+		}
+}
+
 ClassDom StoreWalker::classFromScope(const QStringList& scope) {
 	if(scope.isEmpty())return ClassDom(0);
-	
+
+	//Since another instance of the current file may still be in the code-model this must be testede BEFORE the code-model
+	ClassDom c = findScopeInFile( scope, m_file.data() );
+	if( c ) return c;
+
 	NamespaceDom glob = m_store->globalNamespace();
 	if( !glob ) return ClassDom();
+	c = findScopeInFile( scope, glob );
 	
-	ClassModel* curr =  glob ;
 	
-	QStringList::const_iterator mit = scope.begin();
-	
-	while(curr->isNamespace() && mit != scope.end() && ((NamespaceModel*)curr)->hasNamespace( *mit )) {
-		curr = &(*( ((NamespaceModel*)curr)->namespaceByName( *mit ) ));
-		++mit;
+	QMap<QString, FileDom>::const_iterator it;
+
+	if( c ) {
+		///Check the file that overrides the code-model file
+		it = m_overrides.find( c->fileName() );
+		
+		//Find the class within the file that is overriding the one in code-model.
+		if( it != m_overrides.end() ) {
+			return findScopeInFile( scope, *it );
+		} else {
+			return c;
+		}
+	} else {
+		///Search in all overrides, because they will be added later all at once
+		for( QMap<QString, FileDom>::const_iterator it = m_overrides.begin(); it != m_overrides.end(); ++it ) {
+			c = findScopeInFile( scope, *it );
+			if( c )
+				return c;
+		}
 	}
-	
-	while((curr->isNamespace() || curr->isClass()) && mit != scope.end() && curr->hasClass( *mit )) {
-		ClassList cl = curr->classByName( *mit );
-		curr = &(**cl.begin() );
-		++mit;
-	}
-	
-	if(mit == scope.end()) {
-		return curr;
-	}
-	
+
 	return ClassDom(0);
 }
 
