@@ -115,7 +115,7 @@ PHPSupportPart::PHPSupportPart(QObject *parent, const char *name, const QStringL
             this, SLOT(slotPHPExeExited(KProcess*)));
 
    m_htmlView = new PHPHTMLView(this);
-   mainWindow()->embedPartView(m_htmlView->view(), i18n("PHP"), i18n("PHP"));
+   mainWindow()->embedOutputView(m_htmlView->view(), i18n("PHP"), i18n("PHP"));
    connect( m_htmlView,  SIGNAL(started(KIO::Job*)),
             this, SLOT(slotWebJobStarted(KIO::Job*)));
 
@@ -222,7 +222,6 @@ void PHPSupportPart::slotNewClass() {
 void PHPSupportPart::slotRun() {
    configData = new PHPConfigData(projectDom());
    if (validateConfig()) {
-      mainWindow()->raiseView(m_phpErrorView);
       mainWindow()->raiseView(m_htmlView->view());
       PHPConfigData::InvocationMode mode = configData->getInvocationMode() ;
       if (mode == PHPConfigData::Web) {
@@ -283,7 +282,10 @@ QString PHPSupportPart::getExecuteFile() {
    if (mode == PHPConfigData::Current) {
       KParts::ReadOnlyPart *ro_part = dynamic_cast<KParts::ReadOnlyPart*>(partController()->activePart());
       if (ro_part) {
-         file = QFileInfo(ro_part->url().url()).fileName();
+         if ( configData->getInvocationMode() == PHPConfigData::Web )
+            file = URLUtil::relativePath( project()->projectDirectory(), ro_part->url().path() );
+         else
+            file = ro_part->url().path();
       }
    }
    if (mode == PHPConfigData::Default) {
@@ -328,7 +330,7 @@ void PHPSupportPart::executeInTerminal() {
 
    if (m_htmlView == 0) {
       m_htmlView = new PHPHTMLView(this);
-      mainWindow()->embedPartView(m_htmlView->view(), i18n("PHP"));
+      mainWindow()->embedOutputView(m_htmlView->view(), i18n("PHP"), i18n("PHP") );
    }
 
    m_htmlView->show();
@@ -662,7 +664,7 @@ void PHPSupportPart::customEvent( QCustomEvent* ev )
                LastMethod->setAccess(FunctionModel::Protected);
             else if ( event->name() == "result" ) {
                QString ret = "";
-               if (event->arguments().lower() == "$this") {
+               if (event->arguments().lower() == "$this" && LastClass ) {
                   ret = LastClass->name();
                }
                LastMethod->setResultType(ret);
