@@ -495,7 +495,7 @@ void RubySupportPart::slotRun ()
 
         // Starting WEBrick for a Rails app. Translate a SIGTERM signal sent by KDevelop
         // to a SIGINT expected by WEBrick (ie control&c) to terminate it.
-        cmd += "script/server& \n trap \"kill -s SIGINT $!\" SIGTERM \n wait \n exit 0";
+        cmd += "script/server& \n trap \"kill -s SIGINT $!\" TERM \n wait \n exit 0";
         if (KDevAppFrontend *appFrontend = extension<KDevAppFrontend>("KDevelop/AppFrontend"))
             appFrontend->startAppCommand(project()->projectDirectory(), cmd, false);
     } else {
@@ -541,7 +541,14 @@ QString RubySupportPart::mainProgram() {
 QString RubySupportPart::runDirectory() {
     QString cwd = DomUtil::readEntry(*projectDom(), "/kdevscriptproject/run/globalcwd");
     if (cwd.isEmpty())
-      cwd = project()->buildDirectory();
+    {
+      QString mainProg = DomUtil::readEntry(*projectDom(), "/kdevrubysupport/run/mainprogram");
+      KParts::ReadOnlyPart *ro_part = dynamic_cast<KParts::ReadOnlyPart*>(partController()->activePart());
+      if (mainProg.isEmpty() && ro_part)
+        cwd = ro_part->url().directory();
+      else
+        cwd = project()->buildDirectory();
+    }
     return cwd;
 }
 
