@@ -1,8 +1,8 @@
 /* ANTLR Translator Generator
  * Project led by Terence Parr at http://www.jGuru.com
- * Software rights: http://www.antlr.org/RIGHTS.html
+ * Software rights: http://www.antlr.org/license.html
  *
- * $Id: TokenStreamHiddenTokenFilter.cpp,v 1.3 2003/12/26 22:56:34 harald Exp $
+ * $Id: TokenStreamHiddenTokenFilter.cpp 626096 2007-01-22 06:35:06Z okellogg $
  */
 #include "antlr/TokenStreamHiddenTokenFilter.hpp"
 #include "antlr/CommonHiddenStreamToken.hpp"
@@ -99,7 +99,7 @@ void TokenStreamHiddenTokenFilter::hide(const BitSet& mask)
 	hideMask = mask;
 }
 
-RefToken TokenStreamHiddenTokenFilter::LA(int /*i*/)
+RefToken TokenStreamHiddenTokenFilter::LA(int)
 {
 	return nextMonitoredToken;
 }
