@@ -32,8 +32,27 @@
 #include <qdatastream.h>
 #include <qbuffer.h>
 #include <assert.h>
+
+#include <iostream>
     
 
+class SpecialMutexLocker {
+public:
+  SpecialMutexLocker( QMutex& mutex ) : m_mutex(mutex) {
+    if( !m_mutex.tryLock() ) {
+      m_mutex.lock(); //place breakpoint here to find out when the object is used by another thread
+    }
+  }
+  ~SpecialMutexLocker() {
+    m_mutex.unlock();
+  }
+private:
+  QMutex& m_mutex;
+};
+
+#define LOCK_PROBLEMS_1 SpecialMutexLocker problemLocker( const_cast<QMutex&>(m_problemMutex) );
+#define LOCK_PROBLEMS(x) { SpecialMutexLocker problemLocker( const_cast<QMutex&>(m_problemMutex) ); x; };
+
 //     void Macro::read( QDataStream& stream ) {
 //         stream >> m_idHashValid;
 //         stream >> m_valueHashValid;
@@ -125,7 +144,8 @@ void Driver::reset( ) {
   m_lexerCache.clear();
   m_dependences.clear();
   m_macros.clear();
-  m_problems.clear();
+  
+  LOCK_PROBLEMS ( m_problems.clear(); );
   m_includePaths.clear();
 
   while ( m_parsedUnits.size() ) {
@@ -135,13 +155,14 @@ void Driver::reset( ) {
   }
 }
 
-void Driver::updateIncludePath( const QString& file ) const {
+QStringList Driver::getCustomIncludePath( const QString& ) {
+  return includePaths();
 }
 
 void Driver::remove
   ( const QString & fileName ) {
   m_dependences.remove( fileName );
-  m_problems.remove( fileName );
+    LOCK_PROBLEMS ( m_problems.remove( fileName ); );
     if( !isResolveDependencesEnabled() )
       removeAllMacrosInFile( fileName );
 
@@ -254,9 +275,11 @@ ParsedFilePointer Driver::translationUnit( const QString& fileName ) const {
 
 class Driver::ParseHelper {
   public:
-    ParseHelper( const QString& fileName, bool force, Driver* driver, bool reportMessages = true ) : m_wasReset( false ), m_fileName( fileName ), m_previousFileName( driver->m_currentFileName ),  m_previousLexer( driver->lexer ), m_previousParsedFile( driver->m_currentParsedFile ), m_previousCachedLexedFile( driver->m_currentLexerCache ), m_force( force ), m_driver( driver ), m_lex( m_driver ) {
+    ParseHelper( const QString& fileName, bool force, Driver* driver, bool reportMessages = true, QString includedFrom = QString() ) : m_wasReset( false ), m_fileName( fileName ), m_previousFileName( driver->m_currentFileName ),  m_previousLexer( driver->lexer ), m_previousParsedFile( driver->m_currentParsedFile ), m_previousCachedLexedFile( driver->m_currentLexerCache ), m_force( force ), m_driver( driver ), m_lex( m_driver ) {
       QFileInfo fileInfo( fileName );
       m_driver->m_currentParsedFile = new ParsedFile( fileName, fileInfo.lastModified() );
+      if( !includedFrom.isEmpty() )
+        m_driver->m_currentParsedFile->setIncludedFrom( includedFrom );
 #ifdef CACHELEXER
       m_driver->m_currentLexerCache = new CachedLexedFile( fileName, &m_driver->m_lexerCache );
 #endif
@@ -274,7 +297,11 @@ class Driver::ParseHelper {
       CachedLexedFilePointer lexedFileP = m_driver->m_lexerCache.lexedFile(  HashedString( fileName ) );
       
       m_driver->m_dependences.remove( fileName );
-      m_driver->m_problems.remove( fileName );
+      if( fileName != m_driver->m_currentMasterFileName ) {
+        //For the master-filename, the problems are removed when parseFile(..) is called
+        SpecialMutexLocker l( m_driver->m_problemMutex );
+        m_driver->m_problems.remove( fileName );
+      }
 
       driver->m_currentFileName = fileName;
 
@@ -283,7 +310,7 @@ class Driver::ParseHelper {
 
       m_lex.setReportMessages( reportMessages );
       
-      kdDebug( 9007 ) << "lexing file " << fileName << endl;
+      //kdDebug( 9007 ) << "lexing file " << fileName << endl;
       m_lex.setSource( m_driver->sourceProvider() ->contents( fileName ) );
       if(m_previousCachedLexedFile)
         m_previousCachedLexedFile->merge( *m_driver->m_currentLexerCache );
@@ -292,10 +319,16 @@ class Driver::ParseHelper {
       
       if( !lexedFileP && m_previousParsedFile ) //only add the new cache-instance if a fitting isn't already stored, and if this file was included by another one.
         m_driver->m_lexerCache.addLexedFile( m_driver->m_currentLexerCache );
+
+        //Copy the recursive include-files into the ParsedFile
+        m_driver->m_currentParsedFile->addIncludeFiles( m_driver->m_currentLexerCache->includeFiles() );
+        m_driver->m_currentParsedFile->setSkippedLines( m_lex.skippedLines() );
       }
 
-  
     void parse() {
+      QString oldMasterFileName = m_driver->m_currentMasterFileName; //Change the master-file so problems will be reported correctly
+      m_driver->m_currentMasterFileName = m_absFilePath;
+      
       CachedLexedFilePointer lf = m_driver->m_currentLexerCache; //Set the lexer-cache to zero, so the problems registered through addProblem go directly into the file
       m_driver->m_currentLexerCache = 0;
       
@@ -309,6 +342,8 @@ class Driver::ParseHelper {
       m_driver->fileParsed( *m_driver->m_currentParsedFile );
 
       m_driver->m_currentLexerCache = lf;
+      
+      m_driver->m_currentMasterFileName = oldMasterFileName;
     }
 
     ParsedFilePointer parsedFile() const {
@@ -349,15 +384,15 @@ class Driver::ParseHelper {
 
 
 void Driver::addDependence( const QString & fileName, const Dependence & dep ) {
+
+  // this can happen if the parser was invoked on a snippet of text and not a file
+  if ( fileName.isEmpty() || !m_currentParsedFile ) 
+    return;
+
   //@todo prevent cyclic dependency-loops
   QFileInfo fileInfo( dep.first );
   QString fn = fileInfo.absFilePath();
     
-#ifdef LEXERCACHE
-      if( m_currentLexerCache )
-        m_currentLexerCache->addIncludeFile( file, QDateTime() ); ///The time will be overwritten in CachedLexedFile::merge(...)
-    #endif
-
   if ( !depresolv ) {
     findOrInsertDependenceList( fileName ).insert( fn, dep );
     m_currentParsedFile->addIncludeFile( dep.first, 0, dep.second == Dep_Local );
@@ -365,6 +400,7 @@ void Driver::addDependence( const QString & fileName, const Dependence & dep ) {
   }
 
   QString file = findIncludeFile( dep );
+  
   findOrInsertDependenceList( fileName ).insert( file, dep );
   m_currentParsedFile->addIncludeFile( file, 0, dep.second == Dep_Local );
   
@@ -375,6 +411,9 @@ void Driver::addDependence( const QString & fileName, const Dependence & dep ) {
     addProblem( fileName, p );
     return ;
   }
+  
+  if( m_currentLexerCache )
+     m_currentLexerCache->addIncludeFile( file, QDateTime() ); ///The time will be overwritten in CachedLexedFile::merge(...)
 
   /**What should be done:
    * 1. Lex the file to get all the macros etc.
@@ -387,14 +426,14 @@ void Driver::addDependence( const QString & fileName, const Dependence & dep ) {
 
   IntIncreaser i( m_dependenceDepth );
   if( m_dependenceDepth > m_maxDependenceDepth ) {
-      kdDebug( 9007 ) << "maximum dependence-depth of " << m_maxDependenceDepth << " was reached, " << fileName << " will not be processed" << endl;
+      //kdDebug( 9007 ) << "maximum dependence-depth of " << m_maxDependenceDepth << " was reached, " << fileName << " will not be processed" << endl;
       return;
   }
 
   CachedLexedFilePointer lexedFileP = m_lexerCache.lexedFile(  HashedString( file ) );
   if( lexedFileP ) {
     CachedLexedFile& lexedFile( *lexedFileP );
-    m_currentLexerCache->merge( lexedFile );
+    m_currentLexerCache->merge( lexedFile ); //The ParseHelper will will copy the include-files into the result later
     for( MacroSet::Macros::const_iterator it = lexedFile.definedMacros().macros().begin(); it != lexedFile.definedMacros().macros().end(); ++it ) {
       addMacro( (*it) );
     }
@@ -402,12 +441,13 @@ void Driver::addDependence( const QString & fileName, const Dependence & dep ) {
     return;
   }
 
-  ParseHelper h( file, true, this, false );
+  ParseHelper h( file, true, this, false, m_currentMasterFileName );
 
   /*if ( m_parsedUnits.find(file) != m_parsedUnits.end() )
   	return;*/
 
-  //h.parse();
+  if( shouldParseIncludedFile( m_currentParsedFile ) ) ///Until the ParseHelper is destroyed, m_currentParsedFile will stay the included file
+    h.parse();
 }
 
 void Driver::addProblem( const QString & fileName, const Problem & problem ) {
@@ -431,6 +471,7 @@ QMap< QString, Dependence >& Driver::findOrInsertDependenceList( const QString &
 }
 
 QValueList < Problem >& Driver::findOrInsertProblemList( const QString & fileName ) {
+  LOCK_PROBLEMS_1;
   QMap<QString, QValueList<Problem> >::Iterator it = m_problems.find( fileName );
   if ( it != m_problems.end() )
     return it.data();
@@ -458,6 +499,7 @@ void Driver::insertMacros( const MacroSet& macros ) {
 }
 
 QValueList < Problem > Driver::problems( const QString & fileName ) const {
+  LOCK_PROBLEMS_1;
   QMap<QString, QValueList<Problem> >::ConstIterator it = m_problems.find( fileName );
   if ( it != m_problems.end() )
     return it.data();
@@ -479,14 +521,21 @@ void Driver::clearParsedMacros() {
     }
 }
 
-void Driver::parseFile( const QString& fileName, bool onlyPreProcess, bool force , bool macrosGlobal ) {
-   //if( isResolveDependencesEnabled() )
-    clearParsedMacros(); ///Since everything will be re-lexed, we do not need any old macros
-
-    m_lexerCache.increaseFrame();
+void Driver::parseFile( const QString& fileName, bool onlyPreProcess, bool force , bool macrosGlobal )
+{
+  QString oldMasterFileName = m_currentMasterFileName;
   m_currentMasterFileName = fileName;
   
-  updateIncludePath( fileName );
+ //if( isResolveDependencesEnabled() )
+  clearParsedMacros(); ///Since everything will be re-lexed, we do not need any old macros
+
+  m_lexerCache.increaseFrame();
+
+  //Remove the problems now instead of in ParseHelper, because this way the problems reported by getCustomIncludePath(...) will not be discarded
+  m_problems.remove( fileName );
+  
+  QStringList oldIncludePaths = m_includePaths;
+  m_includePaths = getCustomIncludePath( fileName );
   
     ParseHelper p( fileName, force, this );
     if( !onlyPreProcess ){
@@ -497,8 +546,11 @@ void Driver::parseFile( const QString& fileName, bool onlyPreProcess, bool force
             if( (*it).second.fileName() == fileName ) {
                 (*it).second.setFileName( QString::null );
             }
+        }
     }
-}
+
+  m_includePaths = oldIncludePaths;
+  m_currentMasterFileName = oldMasterFileName;
 }
 
 void Driver::setupLexer( Lexer * lexer ) {
@@ -642,6 +694,27 @@ void Driver::addIncludePath( const QString &path ) {
     m_includePaths << path;
 }
 
+QString Driver::findIncludeFile( const Dependence& dep, const QString& fromFile ) {
+  QString fileName = dep.first;
+  
+  if ( dep.second == Dep_Local ) {
+    QString path = QFileInfo( fromFile ).dirPath( true );
+    QFileInfo fileInfo( QFileInfo( path, fileName ) );
+    if ( fileInfo.exists() && fileInfo.isFile() )
+      return fileInfo.absFilePath();
+  }
+
+  QStringList includePaths = getCustomIncludePath( fromFile );
+  
+  for ( QStringList::ConstIterator it = includePaths.begin(); it != includePaths.end(); ++it ) {
+    QFileInfo fileInfo( *it, fileName );
+    if ( fileInfo.exists() && fileInfo.isFile() )
+      return fileInfo.absFilePath();
+  }
+
+  return QString::null;
+}
+
 QString Driver::findIncludeFile( const Dependence& dep ) const {
   QString fileName = dep.first;
 
@@ -650,7 +723,6 @@ QString Driver::findIncludeFile( const Dependence& dep ) const {
     QFileInfo fileInfo( QFileInfo( path, fileName ) );
     if ( fileInfo.exists() && fileInfo.isFile() )
       return fileInfo.absFilePath();
-
   }
 
   for ( QStringList::ConstIterator it = m_includePaths.begin(); it != m_includePaths.end(); ++it ) {
@@ -668,18 +740,22 @@ void Driver::setResolveDependencesEnabled( bool enabled ) {
     setupPreProcessor();
 }
 
+bool Driver::shouldParseIncludedFile( const ParsedFilePointer& /*file*/) {
+  return false;
+}
+
 void Driver::setupPreProcessor() {}
 
-void Driver::fileParsed( const ParsedFile & fileName ) {
+void Driver::fileParsed( ParsedFile & fileName ) {
   Q_UNUSED( fileName );
 }
 
-void Driver::usingMacro( const Macro& macro, int line, int column ) {
+void Driver::usingMacro( const Macro& macro ) {
     if( m_currentParsedFile )
-        m_currentParsedFile->usedMacros().addMacro( macro, line, column );
+        m_currentParsedFile->usedMacros().addMacro( macro );
 #ifdef CACHELEXER
     if( m_currentLexerCache )
-      m_currentLexerCache->addUsedMacro( macro, line, column );
+      m_currentLexerCache->addUsedMacro( macro );
 #endif
 }
 
@@ -701,7 +777,7 @@ void Driver::usingMacro( const Macro& macro, int line, int column ) {
 // MacroSet::MacroSet() : m_idHashValid( false ), m_valueHashValid( false ) {
 // }
 
-void MacroSet::addMacro( const Macro& macro, int line, int column ) {
+void MacroSet::addMacro( const Macro& macro ) {
   std::pair<Macros::const_iterator, bool> r = m_usedMacros.insert( macro );
   if( !r.second ) {
     //Make sure the macro added later will be used
@@ -768,6 +844,10 @@ MacroSet& ParsedFile::usedMacros() {
   return m_usedMacros;
 }
 
+const MacroSet& ParsedFile::usedMacros() const {
+  return m_usedMacros;
+}
+
 ParsedFile::ParsedFile( const QString& fileName, const QDateTime& timeStamp ) : m_translationUnit( 0 ), m_fileName( fileName ), m_timeStamp( timeStamp ) {
     m_includeFiles.insert( fileName );
 }
@@ -778,6 +858,14 @@ ParsedFile::ParsedFile( const QByteArray& array ) {
     read( d );
 }
 
+QString ParsedFile::includedFrom() const {
+  return m_includedFrom;
+}
+
+void ParsedFile::setIncludedFrom( const QString& str ) {
+  m_includedFrom = str;
+}
+
 QByteArray ParsedFile::serialize() const {
     QByteArray array;
     QBuffer b( array );
@@ -828,6 +916,14 @@ void ParsedFile::setTranslationUnit( const TranslationUnitAST::Node& trans ) {
 //     return m_includeFiles;
 // }
 
+int ParsedFile::skippedLines() const {
+  return m_skippedLines;
+}
+
+void ParsedFile::setSkippedLines( int lines ) {
+  m_skippedLines = lines;
+}
+
 const HashedStringSet& ParsedFile::includeFiles() const {
     return m_includeFiles;
 }
@@ -840,6 +936,10 @@ QDateTime ParsedFile::timeStamp() const {
     return m_timeStamp;
 }
 
+void ParsedFile::addIncludeFiles( const HashedStringSet& includeFiles ) {
+    m_includeFiles += includeFiles;
+}
+
 void ParsedFile::addIncludeFile( const QString& includePath, const ParsedFilePointer& parsed, bool localInclude ) {
     m_includeFiles.insert( includePath );
     if( parsed )
