@@ -22,6 +22,77 @@
 #include <kdebug.h>
 #include <kdatastream.h>
 
+///Little helper-functions to save a lot of typing and possible errors
+template<class MapContainer>
+bool eachCanUpdate( const MapContainer& old, const MapContainer& newMap ) {
+  if( old.size() != newMap.size() ) return false;
+
+  typename MapContainer::const_iterator oldIt = old.begin();
+  typename MapContainer::const_iterator newIt = newMap.begin();
+  while( oldIt != old.end() ) {
+    typedef typename MapContainer::mapped_type ListType;
+    if( (*oldIt).size() != (*newIt).size() ) return false;
+    typename ListType::const_iterator it1 = (*oldIt).begin();
+    typename ListType::const_iterator it2 = (*newIt).begin();
+
+    while( it1 != (*oldIt).end() ) {
+      if( !(*it1)->canUpdate( *it2 ) ) return false;
+      ++it1;
+      ++it2;
+    }
+    ++oldIt;
+    ++newIt;
+  }
+  return true;
+}
+
+template<class MapContainer>
+void eachUpdate( MapContainer& old, const MapContainer& newMap  ) {
+  if( old.size() != newMap.size() ) kdError( 9007 ) << "error in eachUpdate(...) 1" << endl;
+  typename MapContainer::iterator oldIt = old.begin();
+  typename MapContainer::const_iterator newIt = newMap.begin();
+  while( oldIt != old.end() ) {
+    if( (*oldIt).size() != (*newIt).size() ) kdError( 9007 ) << "error in eachUpdate(...) 2" << endl;
+    typedef typename MapContainer::mapped_type ListType;
+    typename ListType::iterator it1 = (*oldIt).begin();
+    typename ListType::const_iterator it2 = (*newIt).begin();
+    while( it1 != (*oldIt).end() ) {
+      (*it1)->update( *it2 );
+      ++it1;
+      ++it2;
+    }
+    ++oldIt;
+    ++newIt;
+  }
+}
+
+///Versions for contains that do not contain maps again
+template<class MapContainer>
+bool eachCanUpdateSingle( const MapContainer& old, const MapContainer& newMap ) {
+  if( old.size() != newMap.size() ) return false;
+
+  typename MapContainer::const_iterator oldIt = old.begin();
+  typename MapContainer::const_iterator newIt = newMap.begin();
+  while( oldIt != old.end() ) {
+    if( !(*oldIt)->canUpdate( *newIt ) ) return false;
+    ++oldIt;
+    ++newIt;
+  }
+  return true;
+}
+
+template<class MapContainer>
+void eachUpdateSingle( MapContainer& old, const MapContainer& newMap  ) {
+  if( old.size() != newMap.size() ) kdError( 9007 ) << "error in eachUpdate(...) 1" << endl;
+  typename MapContainer::iterator oldIt = old.begin();
+  typename MapContainer::const_iterator newIt = newMap.begin();
+  while( oldIt != old.end() ) {
+    (*oldIt)->update( *newIt );
+    ++oldIt;
+    ++newIt;
+  }
+}
+
 CodeModel::CodeModel()
 {
     wipeout();
@@ -314,12 +385,22 @@ bool CodeModel::hasFile( const QString & name ) const
 
 FileDom CodeModel::fileByName( const QString & name )
 {
-    return m_files.contains(name) ? m_files[ name ] : FileDom();
+    QMap<QString, FileDom>::const_iterator it = m_files.find( name );
+    if( it != m_files.end() ) {
+      return *it;
+    } else {
+      return FileDom();
+    }
 }
 
 const FileDom CodeModel::fileByName( const QString & name ) const
 {
-    return m_files.contains(name) ? m_files[ name ] : FileDom();
+    QMap<QString, FileDom>::const_iterator it = m_files.find( name );
+    if( it != m_files.end() ) {
+      return *it;
+    } else {
+      return FileDom();
+    }
 }
 
 void CodeModel::addNamespace( NamespaceDom target, NamespaceDom source )
@@ -565,6 +646,20 @@ void CodeModelItem::setEndPosition( int line, int column )
     m_endColumn = column;
 }
 
+void CodeModelItem::update( const CodeModelItem* i ) {
+  m_startLine = i->m_startLine;
+  m_startColumn = i->m_startColumn;
+  m_endLine = i->m_endLine;
+  m_endColumn = i->m_endColumn;
+}
+
+bool CodeModelItem::canUpdate( const CodeModelItem* i ) const {
+  if( i->m_kind != m_kind || i->m_name != m_name )
+    return false;
+  return true;
+}
+
+
 // ------------------------------------------------------------------------
 NamespaceModel::NamespaceModel( CodeModel* model )
     : ClassModel( model )
@@ -880,6 +975,28 @@ bool ClassModel::addEnum( EnumDom e )
     return true;
 }
 
+void ClassModel::update( const ClassModel* klass ) {
+  CodeModelItem::update( klass );
+  eachUpdate( m_classes, klass->m_classes ) ;
+  eachUpdate( m_functions, klass->m_functions ) ;
+  eachUpdate( m_functionDefinitions, klass->m_functionDefinitions ) ;
+  eachUpdateSingle( m_variables, klass->m_variables ) ;
+  eachUpdateSingle( m_enumerators, klass->m_enumerators ) ;
+  eachUpdate( m_typeAliases, klass->m_typeAliases );
+}
+
+bool ClassModel::canUpdate( const ClassModel* klass ) const {
+    if( !CodeModelItem::canUpdate( klass ) )
+      return false;
+    
+    return eachCanUpdate( m_classes, klass->m_classes ) &&
+        eachCanUpdate( m_functions, klass->m_functions ) &&
+        eachCanUpdate( m_functionDefinitions, klass->m_functionDefinitions ) &&
+        eachCanUpdateSingle( m_variables, klass->m_variables ) &&
+        eachCanUpdateSingle( m_enumerators, klass->m_enumerators ) &&
+        eachCanUpdate( m_typeAliases, klass->m_typeAliases );
+}
+
 void ClassModel::removeEnum( EnumDom e )
 {
     m_enumerators.remove( e->name() );
@@ -1064,6 +1181,19 @@ void FunctionModel::removeArgument( ArgumentDom arg )
     m_arguments.remove( arg );
 }
 
+void FunctionModel::update( const FunctionModel* i ) {
+  CodeModelItem::update( i );
+}
+
+bool FunctionModel::canUpdate( const FunctionModel* i ) const {
+  if( !CodeModelItem::canUpdate( i ) )
+    return false;
+  if( m_resultType != i->m_resultType || m_arguments.count() != i->m_arguments.count() || m_scope != i->m_scope )
+    return false;
+  return true;
+}
+
+
 // ------------------------------------------------------------------------
 VariableModel::VariableModel( CodeModel* model )
     : CodeModelItem( Variable, model)
@@ -1348,6 +1478,50 @@ void NamespaceModel::write( QDataStream & stream ) const
     (*it).write( stream );
 }
 
+bool NamespaceModel::canUpdate( const NamespaceModel* ns ) const {
+  if( !ClassModel::canUpdate( ns ) )
+    return false;
+    
+    const NamespaceAliasModelList& aliases = namespaceAliases();
+    const NamespaceImportModelList& imports = namespaceImports();
+    const NamespaceAliasModelList& aliases2 = ns->namespaceAliases();
+    const NamespaceImportModelList& imports2 = ns->namespaceImports();
+
+    if( aliases.size() != aliases2.size() ) return false;
+    if( imports.size() != imports2.size() ) return false;
+
+    ///Test if all aliases are same, if not return false
+    NamespaceModel::NamespaceAliasModelList::const_iterator it_al1 = aliases.begin();
+    NamespaceModel::NamespaceAliasModelList::const_iterator it_al2 = aliases2.begin();
+    while( it_al1 != aliases.end() ) {
+      if( !(*it_al1 == *it_al2) )
+        return false;
+
+      ++it_al1;
+      ++it_al2;
+    }
+    
+    ///Test if all imports are same, if not return false
+    NamespaceModel::NamespaceImportModelList::const_iterator it_ip1 = imports.begin();
+    NamespaceModel::NamespaceImportModelList::const_iterator it_ip2 = imports2.begin();
+    while( it_ip1 != imports.end() ) {
+      if( !(*it_ip1 == *it_ip2) )
+        return false;
+
+      ++it_ip1;
+      ++it_ip2;
+    }
+    
+    return eachCanUpdateSingle( m_namespaces, ns->m_namespaces );
+}
+
+void NamespaceModel::update( const NamespaceModel* ns )
+{
+  ClassModel::update( ns );
+
+    eachUpdateSingle( m_namespaces, ns->m_namespaces );
+}
+
 void FileModel::read( QDataStream & stream )
 {
     stream >> m_groupId;
@@ -1469,6 +1643,18 @@ void VariableModel::write( QDataStream & stream ) const
 		stream << m_access << m_static << m_type << m_isEnumeratorVariable;
 }
 
+void VariableModel::update( const VariableModel* i ) {
+  CodeModelItem::update( i );
+}
+
+bool VariableModel::canUpdate( const VariableModel* i ) const {
+  if( !CodeModelItem::canUpdate( i ) )
+    return false;
+  if( m_access != i->m_access || m_static != i->m_static || m_type != i->m_type || m_isEnumeratorVariable != i->m_isEnumeratorVariable )
+    return false;
+  return true;
+}
+
 // -------------------------------------------------------
 EnumModel::EnumModel( CodeModel * model )
     : CodeModelItem( Enum, model)
@@ -1557,6 +1743,19 @@ void EnumModel::removeEnumerator( EnumeratorDom e )
     m_enumerators.remove( e->name() );
 }
 
+void EnumModel::update( const EnumModel* i ) {
+  CodeModelItem::update( i );
+}
+
+bool EnumModel::canUpdate( const EnumModel* i ) const {
+  if( !CodeModelItem::canUpdate( i ) )
+    return false;
+  ///@todo check not complete
+  if( m_access != i->m_access || m_enumerators.count() != i->m_enumerators.count() )
+    return false;
+  return true;
+}
+
 // ---------------------------------------------------------------
 TypeAliasModel::TypeAliasModel( CodeModel * model )
     : CodeModelItem( TypeAlias, model )
@@ -1587,6 +1786,21 @@ void TypeAliasModel::setType( const QString & type )
     m_type = type;
 }
 
+void TypeAliasModel::update( const TypeAliasModel* i ) {
+  CodeModelItem::update( i );
+}
+
+bool TypeAliasModel::canUpdate( const TypeAliasModel* i ) const {
+  if( !CodeModelItem::canUpdate( i ) )
+    return false;
+  return m_type == i->m_type;
+}
+
+void FileModel::update( const FileModel* file ) {
+  m_parseResult = file->m_parseResult;
+  NamespaceModel::update( file );
+}
+
 FileList FileModel::wholeGroup() {
     if( isSingleGroup( m_groupId ) ) return ( FileList() << FileDom(this) );
     return codeModel()->getGroup( m_groupId );
