@@ -47,18 +47,18 @@ public:
         m_changed(false)
     {
     }
-    
+
     PropertyItem(PropertyEditor *editor, KListViewItem *parent, MultiProperty *property)
         :KListViewItem(parent, property->description()), m_editor(editor),
         m_property(property), m_changed(false)
     {
     }
-    
+
 /*    int type() const
     {
         return m_property->type();
     }
-    
+
     QString name() const
     {
         return m_property->name();
@@ -68,7 +68,7 @@ public:
     {
         return m_property;
     }
-    
+
     virtual void paintCell(QPainter *p, const QColorGroup &cg, int column, int width, int align)
     {
         if ((column == 0) && m_changed)
@@ -89,19 +89,23 @@ public:
             else
                 valueToDraw = m_property->value();
             QColorGroup icg(cg);
+#ifndef PURE_QT
             icg.setColor(QColorGroup::Background, backgroundColor());
+#else
+            icg.setColor(QColorGroup::Background, white);
+#endif
             m_editor->machine(m_property)->propertyEditor->drawViewer(p, icg, r, valueToDraw);
             return;
         }
         KListViewItem::paintCell(p, cg, column, width, align);
     }
-    
+
     virtual void setup()
     {
         KListViewItem::setup();
         setHeight(static_cast<int>(height()*1.5));
     }
-    
+
     void setChanged(bool changed)
     {
         m_changed = changed;
@@ -126,7 +130,7 @@ public:
     {
         init();
     }
-        
+
     virtual void paintCell(QPainter *p, const QColorGroup &cg, int column, int width, int align)
     {
         if (column == 0)
@@ -160,12 +164,11 @@ public:
         setSelectable(false);
     }
 };
-
 PropertyEditor::PropertyEditor(QWidget *parent, const char *name)
     :KListView(parent, name)
 {
     setSorting(-1);
-    
+
     addColumn(i18n("Name"));
     addColumn(i18n("Value"));
     setAllColumnsShowFocus(true);
@@ -181,14 +184,18 @@ PropertyEditor::PropertyEditor(QWidget *parent, const char *name)
 
     m_currentEditItem = 0;
     m_doubleClickForEdit = true;
-    m_lastClickedItem = 0;    
+    m_lastClickedItem = 0;
     m_currentEditWidget = 0;
     m_list = 0;
-    
+
     m_currentEditArea = new QWidget(viewport());
     m_currentEditArea->hide();
     m_undoButton = new QPushButton(m_currentEditArea);
+#ifndef PURE_QT
     m_undoButton->setPixmap(SmallIcon("undo"));
+#else
+    m_undoButton->setPixmap( QPixmap("undo.xpm") );
+#endif
     m_undoButton->setSizePolicy(QSizePolicy::Maximum, QSizePolicy::MinimumExpanding);
     m_undoButton->resize(m_undoButton->height(), m_undoButton->height());
     m_undoButton->hide();
@@ -256,19 +263,19 @@ void PropertyEditor::addChildProperties(PropertyItem *parent)
 {
     MultiProperty *prop = parent->property();
     //force machine creation to get detailed properties appended to current multiproperty
-    if ( !m_registeredForType.contains(prop->type())
+    if ( !m_registeredForType.contains(prop->name())
         && (PropertyMachineFactory::getInstance()->hasDetailedEditors(prop->type())) )
     {
         //FIXME: find better solution
         machine(prop);
     }
-        
-    qWarning("seeking children: count: %d", prop->details.count());
+
+//     qWarning("seeking children: count: %d", prop->details.count());
 
     parent->setOpen(true);
     for (QValueList<ChildProperty>::iterator it = prop->details.begin(); it != prop->details.end(); ++it)
     {
-        qWarning("found child %s", (*it).name().ascii());
+//         qWarning("found child %s", (*it).name().ascii());
         new PropertyItem(this, parent, new MultiProperty(&m_detailedList, &(*it)));
     }
 }
@@ -278,9 +285,9 @@ void PropertyEditor::clearProperties()
     m_detailedList.clear();
     if (!m_list)
         return;
-    
+
     hideEditor();
-    
+
     disconnect(m_list, SIGNAL(propertyValueChanged(Property*)), this, SLOT(propertyValueChanged(Property*)));
     clear();
     delete m_list;
@@ -289,17 +296,18 @@ void PropertyEditor::clearProperties()
 
 void PropertyEditor::propertyValueChanged(Property *property)
 {
+//     qWarning("PropertyEditor::propertyValueChanged");
     if (m_currentEditWidget->propertyName() == property->name())
         m_currentEditWidget->setValue(property->value(), false);
     else
     {
-        //repaint all items
+//        repaint all items
         QListViewItemIterator it(this);
         while (it.current())
         {
             repaintItem(it.current());
             ++it;
-        }        
+        }
     }
 }
 
@@ -307,17 +315,19 @@ void PropertyEditor::propertyChanged(MultiProperty *property, const QVariant &va
 {
     if (!property)
         return;
-    
-    kdDebug() << "editor: assign " << property->name().latin1() << " to " << value.toString().latin1() << endl;
+
+    qWarning("editor: assign %s to %s", property->name().latin1(), value.toString().latin1());
     property->setValue(value, false);
-    
+
     //highlight changed properties
     if (m_currentEditItem && (m_currentEditItem->property() == property))
     {
         m_currentEditItem->setChanged(true);
         repaintItem(m_currentEditItem);
     }
-    
+
+    emit changed();
+
 /*    if (m_list->contains(name))
     {
         (*m_list)[name]->setValue(value, false);
@@ -387,7 +397,7 @@ PropertyWidget* PropertyEditor::prepareEditor(PropertyItem *item)
     PropertyWidget *editorWidget = 0;
 /*    if (item->depth() >= 2)
     {
-        editorWidget = machine(item->name())->propertyEditor;    
+        editorWidget = machine(item->name())->propertyEditor;
         editorWidget->setValue(m_accessor->value(item->name()), false);
     }
     else
@@ -429,23 +439,23 @@ void PropertyEditor::slotClicked(QListViewItem *item)
 
 Machine *PropertyEditor::machine(MultiProperty *property)
 {
-    int type = property->type();
+//    int type = property->type();
     QString name = property->name();
     QMap<QString, QVariant> values = property->valueList();
-    if (m_registeredForType[type] == 0)
+    if (m_registeredForType[name] == 0)
     {
-        m_registeredForType[type] = PropertyMachineFactory::getInstance()->machineForProperty(property);
-        connect(m_registeredForType[type]->propertyEditor, SIGNAL(propertyChanged(MultiProperty*, const QVariant&)),
-            this, SLOT(propertyChanged(MultiProperty*, const QVariant&)));
-        m_registeredForType[type]->propertyEditor->reparent(m_currentEditArea, 0, m_currentEditArea->childrenRect().topLeft());
-        m_registeredForType[type]->propertyEditor->hide();
+        m_registeredForType[name] = PropertyMachineFactory::getInstance()->machineForProperty(property);
+        connect(m_registeredForType[name]->propertyEditor, SIGNAL(propertyChanged(MultiProperty*, const QVariant&)),
+		this, SLOT(propertyChanged(MultiProperty*, const QVariant&)));
+        m_registeredForType[name]->propertyEditor->reparent(m_currentEditArea, 0, m_currentEditArea->childrenRect().topLeft());
+        m_registeredForType[name]->propertyEditor->hide();
     }
-    return m_registeredForType[type];
+    return m_registeredForType[name];
 }
 
 void PropertyEditor::clearMachineCache()
 {
-    for (QMap<int, Machine* >::iterator it = m_registeredForType.begin(); it != m_registeredForType.end(); ++it)
+    for (QMap<QString, Machine* >::iterator it = m_registeredForType.begin(); it != m_registeredForType.end(); ++it)
     {
         delete it.data();
     }
@@ -454,10 +464,10 @@ void PropertyEditor::clearMachineCache()
 
 void PropertyEditor::undo()
 {
-    if ((m_currentEditItem == 0) || (m_currentEditWidget == 0) 
+    if ((m_currentEditItem == 0) || (m_currentEditWidget == 0)
         || (!m_currentEditWidget->isVisible()))
         return;
-    
+
     m_currentEditWidget->undo();
     m_currentEditItem->setChanged(false);
     repaintItem(m_currentEditItem);
@@ -465,4 +475,6 @@ void PropertyEditor::undo()
 
 }
 
+#ifndef PURE_QT
 #include "propertyeditor.moc"
+#endif
