@@ -7,7 +7,7 @@
 #include <qradiobutton.h>
 #include <qspinbox.h>
 #include <qcheckbox.h>
-
+#include <kdebug.h>
 #include <kapplication.h>
 #include <kconfig.h>
 
@@ -38,50 +38,55 @@ string ASStringIterator::nextLine()
 }
 
 
-
-
-KDevFormatter::KDevFormatter()
+KDevFormatter::KDevFormatter(const QMap<QString, QVariant>& options)
 {
-	KConfig *config = kapp->config();
-	config->setGroup("AStyle");
+// 	for ( QMap<QString, QVariant>::ConstIterator iter = options.begin();iter != options.end();iter++ )
+// 	{
+// 		kdDebug ( 9009 ) << "format: " << iter.key() << "=" << iter.data()  << endl;
+// 	}
+
+	setCStyle();
 
 	// style
-	QString s = config->readEntry("FStyle");
-
+	QString s = options["FStyle"].toString();
 	if ( predefinedStyle( s ) )
 	{
 		return;
 	}
 
   // fill
-	int wsCount = config->readNumEntry("FillCount",2);
-  if (config->readEntry("Fill", "Tabs") == "Tabs")
+	int wsCount = options["FillCount"].toInt();
+  if (options["Fill"].toString() == "Tabs")
   {
-	  setTabIndentation(wsCount, config->readBoolEntry("FillForce",false) );
+	  setTabIndentation(wsCount, options["FillForce"].toBool() );
 	  m_indentString = "\t";
   } else
   {
 	  setSpaceIndentation(wsCount);
 	  m_indentString = "";
 	  m_indentString.fill(' ', wsCount);
-	  setTabSpaceConversionMode(config->readBoolEntry("FillForce",true));
   }
 
+  setTabSpaceConversionMode(options["FillForce"].toBool());
+  setEmptyLineFill(options["Fill_EmptyLines"].toBool());
+
   // indent
-  setSwitchIndent(config->readBoolEntry("IndentSwitches", false));
-  setClassIndent(config->readBoolEntry("IndentClasses", false));
-  setCaseIndent(config->readBoolEntry("IndentCases", false));
-  setBracketIndent(config->readBoolEntry("IndentBrackets", false));
-  setNamespaceIndent(config->readBoolEntry("IndentNamespaces", true));
-  setLabelIndent(config->readBoolEntry("IndentLabels", true));
+  setSwitchIndent(options["IndentSwitches"].toBool());
+  setClassIndent(options["IndentClasses"].toBool());
+  setCaseIndent(options["IndentCases"].toBool());
+  setBracketIndent(options["IndentBrackets"].toBool());
+  setNamespaceIndent(options["IndentNamespaces"].toBool());
+  setLabelIndent(options["IndentLabels"].toBool());
+  setBlockIndent(options["IndentBlocks"].toBool());
+  setPreprocessorIndent(options["IndentPreprocessors"].toBool());
 
   // continuation
-  setMaxInStatementIndentLength(config->readNumEntry("MaxStatement", 40));
-  if (config->readNumEntry("MinConditional", -1) != -1)
-    setMinConditionalIndentLength(config->readNumEntry("MinConditional"));
+  setMaxInStatementIndentLength(options["MaxStatement"].toInt());
+  if (options["MinConditional"].toInt() != -1)
+    setMinConditionalIndentLength(options["MinConditional"].toInt());
 
   // brackets
-  s = config->readEntry("Brackets", "None");
+  s = options["Brackets"].toString();
   if (s == "Break")
 	  setBracketFormatMode(astyle::BREAK_MODE);
   else if (s == "Attach")
@@ -91,24 +96,24 @@ KDevFormatter::KDevFormatter()
   else
 	  setBracketFormatMode(astyle::NONE_MODE);
 
-  // padding
-  setOperatorPaddingMode(config->readBoolEntry("PadOperators", false));
-  setParensInsidePaddingMode(config->readBoolEntry("PadParenthesesIn", false));
-  setParensOutsidePaddingMode(config->readBoolEntry("PadParenthesesOut", false));
-  setParensUnPaddingMode(config->readBoolEntry("PadParenthesesUn", false));
-
-  // oneliner
-  setBreakOneLineBlocksMode(config->readBoolEntry("KeepBlocks", false));
-  setSingleStatementsMode(config->readBoolEntry("KeepStatements", false));
-
+  setBreakClosingHeaderBracketsMode(options["BracketsCloseHeaders"].toBool());
   // blocks
-  setBreakBlocksMode(config->readBoolEntry("BlockBreak",false));
-  if (config->readBoolEntry("BlockBreakAll",false)){
+  setBreakBlocksMode(options["BlockBreak"].toBool());
+  if (options["BlockBreakAll"].toBool()){
 	  setBreakBlocksMode(true);
 	  setBreakClosingHeaderBlocksMode(true);
   }
-  setBreakElseIfsMode(config->readBoolEntry("BlockIfElse",false));
+  setBreakElseIfsMode(options["BlockIfElse"].toBool());
 
+  // padding
+  setOperatorPaddingMode(options["PadOperators"].toBool());
+  setParensInsidePaddingMode(options["PadParenthesesIn"].toBool());
+  setParensOutsidePaddingMode(options["PadParenthesesOut"].toBool());
+  setParensUnPaddingMode(options["PadParenthesesUn"].toBool());
+
+  // oneliner
+  setBreakOneLineBlocksMode(!options["KeepBlocks"].toBool());
+  setSingleStatementsMode(!options["KeepStatements"].toBool());
 }
 
 KDevFormatter::KDevFormatter( AStyleWidget * widget )
