@@ -166,7 +166,6 @@ ClassViewPart::ClassViewPart(QObject *parent, const char *name, const QStringLis
     connect( core(), SIGNAL(languageChanged()), this, SLOT(slotProjectOpened()) );
     connect( partController(), SIGNAL(activePartChanged(KParts::Part*)),
         this, SLOT(activePartChanged(KParts::Part*)));
-    connect( m_widget, SIGNAL(removedNamespace(const QString&)), this, SLOT(removeNamespace(const QString& )));
 }
 
 bool ClassViewPart::jumpedToItem( ItemDom item ) {
@@ -204,7 +203,9 @@ void ClassViewPart::setupActions( )
     m_functionsnav->setWhatsThis(i18n("<b>Function navigator</b><p>Navigates over functions contained in the file."));
 //    m_functionsnav->view()->setCurrentText(NAV_NODEFINITION);
     m_functionsnav->view()->setDefaultText(NAV_NODEFINITION);
-    
+
+    new KAction( i18n("Focus Navigator"), 0, this, SLOT(slotFocusNavbar()), actionCollection(), "focus_navigator" );
+
     if (langHasFeature(KDevLanguageSupport::Classes))
     {
         KAction *ac = new KAction(i18n("Class Inheritance Diagram"), "view_tree", 0, this, SLOT(graphicalClassView()), actionCollection(), "inheritance_dia");
@@ -267,5 +268,9 @@ void ClassViewPart::activePartChanged( KParts::Part * part)
             navigator, SLOT(slotCursorPositionChanged()) );
     }
 }
+void ClassViewPart::slotFocusNavbar()
+{
+    m_functionsnav->view()->setFocus();
+}
 
 #include "classviewpart.moc"
