@@ -41,14 +41,48 @@ void FileTreeViewItem::hideOrShow()
     }
 }
 
+bool FileTreeViewItem::changeActiveDir( const QString& olddir, const QString& newdir, bool foundolddir, bool foundnewdir )
+{
+    kdDebug( 9017 ) << "FileTreeViewItem::changeActiveDir(): " + olddir << " new: " << newdir << " for: " << path() << endl;
+
+    if ( this->path() == olddir && isDir() && m_isActiveDir )
+    {
+        m_isActiveDir = false;
+        setVisible( listView()->shouldBeShown( this ) );
+        foundolddir = true;
+        repaint();
+    }
+
+    if ( this->path() == newdir && isDir() && !m_isActiveDir )
+    {
+        m_isActiveDir = true;
+        setVisible( listView()->shouldBeShown( this ) );
+        foundnewdir = true;
+        repaint();
+    }
+
+    if( foundnewdir && foundolddir )
+        return true;
+
+    FileTreeViewItem* item = static_cast<FileTreeViewItem*>( firstChild() );
+    while( item )
+    {
+        if ( item->changeActiveDir( olddir, newdir, foundnewdir, foundolddir ) )
+            return true;
+        else
+            item = static_cast<FileTreeViewItem*>(item->nextSibling());
+    }
+    return false;
+}
+
 ///////////////////////////////////////////////////////////////////////////////
 
 bool FileTreeViewItem::setProjectFile( QString const & path, bool pf )
 {
-    kdDebug( 9017 ) << "FileTreeViewItem::setProjectFile(): " + path << " projectfile: " << pf << endl;
 
-    if ( this->path() == path )
+    if ( this->path() == path && isProjectFile() != pf )
     {
+        kdDebug( 9017 ) << "FileTreeViewItem::setProjectFile(): " + path << " projectfile: " << pf << endl;
         m_isProjectFile = pf;
         setVisible( listView()->shouldBeShown( this ) );
         repaint();
@@ -78,6 +112,13 @@ void FileTreeViewItem::paintCell(QPainter *p, const QColorGroup &cg,
         p->setFont( font );
     }
 
+    if( isActiveDir() )
+    {
+        QFont font( p->font() );
+        font.setItalic( true );
+        p->setFont( font );
+    }
+
     QListViewItem::paintCell( p, cg, column, width, alignment );
 }
 
