@@ -50,6 +50,13 @@ CompileErrorFilter::ErrorFormat* CompileErrorFilter::errorFormats()
 		ErrorFormat( "([^: \\t]+)\\(([0-9]+)\\):([^0-9]+)", 1, 2, 3, "intel" ),
 		//libtool link
 		ErrorFormat( "(libtool):( link):( warning): ", 0, 0, 0 ),
+		// ld 
+		ErrorFormat( "undefined reference", 0, 0, 0 ),
+		ErrorFormat( "undefined symbol", 0, 0, 0 ),
+		ErrorFormat( "ld: cannot find", 0, 0, 0 ),
+		ErrorFormat( "No such file", 0, 0, 0 ),
+		// make
+ 		ErrorFormat( "No rule to make target", 0, 0, 0 ),
 		// Fortran
 		ErrorFormat( "\"(.*)\", line ([0-9]+):(.*)", 1, 2, 3 ),
 		// Jade
@@ -65,6 +72,7 @@ CompileErrorFilter::ErrorFormat* CompileErrorFilter::errorFormats()
 	};
 
 	return formats;
+
 }
 
 void CompileErrorFilter::processLine( const QString& line )
@@ -84,13 +92,13 @@ void CompileErrorFilter::processLine( const QString& line )
 		QRegExp& regExp = format->expression;
 
 		if ( regExp.search( line ) != -1 ) {
-	                hasmatch = true;
-        	        file    = regExp.cap( format->fileGroup );
-	                lineNum = regExp.cap( format->lineGroup ).toInt() - 1;
-	                text    = regExp.cap( format->textGroup );
+			hasmatch = true;
+			file    = regExp.cap( format->fileGroup );
+			lineNum = regExp.cap( format->lineGroup ).toInt() - 1;
+			text    = regExp.cap( format->textGroup );
 			compiler = format->compiler;
 			QString cap = regExp.cap(3);
-			if (cap.contains("warning", false) || cap.contains("Warnung", false))
+			if (cap.contains("warning:", false) || cap.contains("Warnung:", false))
 				isWarning = true;
 			if (regExp.cap(3).contains("instantiated from", false)) {
 				isInstantiationInfo = true;
