@@ -48,6 +48,9 @@ public slots:
   virtual void slotTextChangedDelayed();
 
 protected:
+    void maybeUpdateSelection();
+    virtual void itemSelectionChanged();
+    void QStringList_unique( QStringList & list );
     QStringList wildCardCompletion( const QString & text );
     QStringList m_items;
     QuickOpenPart* m_part;
