@@ -8,6 +8,7 @@
 
 class QPopupMenu;
 class MultiBuffer;
+class QTimer;
 
 #include <kparts/part.h>
 #include <ktexteditor/markinterface.h>
@@ -36,6 +37,9 @@ public:
 
   QWidget * findPartWidget( KParts::Part * part );
 
+public slots:
+  void setLineNumberDelayed();
+
 private slots:
 
   void popupAboutToShow();
@@ -52,7 +56,11 @@ private:
   // This list is used to save line/col information for not yet activated editor views.
   QValueList< MultiBuffer* > m_editorParts;
 
+  QTimer* m_delayedLineTimer;
   bool m_delayedViewCreationCompatibleUI;
+  KParts::Part *m_delayedPart;
+  int m_delayedLine;
+  int m_delayedCol;
 };
 
 
