@@ -18,7 +18,6 @@
 #include <kpopupmenu.h>
 #include <kdebug.h>
 #include <kdevgenericfactory.h>
-#include <klocale.h>
 #include <kprocess.h>
 #include <kmessagebox.h>
 #include <kapplication.h>
@@ -30,16 +29,17 @@
 #include "kdevcore.h"
 #include "kdevmakefrontend.h"
 #include "kdevdifffrontend.h"
+#include "kdevplugininfo.h"
 #include "commitdlg.h"
 #include "execcommand.h"
 
-static const KAboutData data("kdevperforce", I18N_NOOP("Perforce"), "1.0");
+static const KDevPluginInfo data("kdevperforce");
 
 typedef KDevGenericFactory<PerforcePart> PerforceFactory;
-K_EXPORT_COMPONENT_FACTORY( libkdevperforce, PerforceFactory( &data ) )
+K_EXPORT_COMPONENT_FACTORY( libkdevperforce, PerforceFactory( data ) )
 
 PerforcePart::PerforcePart( QObject *parent, const char *name, const QStringList & )
-    : KDevPlugin( "Perforce", "perforce", parent, name ? name : "PerforcePart" )
+    : KDevVersionControl( &data, parent, name ? name : "PerforcePart" )
 {
     setInstance(PerforceFactory::instance());
     setupActions();
@@ -88,7 +88,7 @@ void PerforcePart::contextMenu(QPopupMenu *popup, const Context *context)
 {
     if (context->hasType( Context::FileContext )) {
         const FileContext *fcontext = static_cast<const FileContext*>(context);
-        popupfile = fcontext->fileName();
+        popupfile = fcontext->urls().first().path();
         QFileInfo fi( popupfile );
         popup->insertSeparator();
 
@@ -140,7 +140,8 @@ void PerforcePart::execCommand( const QString& cmd, const QString& filename )
     command += " && p4 " + cmd + " ";
     command += name;
 
-    makeFrontend()->queueCommand(dir, command);
+    if (KDevMakeFrontend *makeFrontend = extension<KDevMakeFrontend>("KDevelop/MakeFrontend"))
+        makeFrontend->queueCommand(dir, command);
 }
 
 void PerforcePart::edit( const QString& filename )
@@ -152,7 +153,7 @@ void PerforcePart::revert( const QString& filename )
 {
     if ( KMessageBox::questionYesNo( 0,
             i18n("Do you really want to revert "
-                 "the file %1 and lose all your changes?").arg( filename ) ) == KMessageBox::Yes ) {
+                 "the file %1 and lose all your changes?").arg( filename ), QString::null, i18n("Revert"), i18n("Do Not Revert") ) == KMessageBox::Yes ) {
         execCommand( "revert", filename );
     }
 }
@@ -182,7 +183,8 @@ void PerforcePart::commit( const QString& filename )
     QString command("echo " + message);
     command += " | p4 submit -i";
 
-    makeFrontend()->queueCommand("", command);
+    if (KDevMakeFrontend *makeFrontend = extension<KDevMakeFrontend>("KDevelop/MakeFrontend"))
+        makeFrontend->queueCommand("", command);
 }
 
 
@@ -206,7 +208,8 @@ void PerforcePart::update( const QString& filename )
     command += " && p4 sync ";
     command += name;
 
-    makeFrontend()->queueCommand(dir, command);
+    if (KDevMakeFrontend *makeFrontend = extension<KDevMakeFrontend>("KDevelop/MakeFrontend"))
+        makeFrontend->queueCommand(dir, command);
 }
 
 
@@ -251,12 +254,12 @@ void PerforcePart::slotDiffFinished( const QString& diff, const QString& err )
     }
 
     if ( diff.isEmpty() && !err.isEmpty() ) {
-        KMessageBox::detailedError( 0, i18n("P4 outputted errors during diff."), err, i18n("Errors During Diff") );
+        KMessageBox::detailedError( 0, i18n("P4 output errors during diff."), err, i18n("Errors During Diff") );
         return;
     }
 
     if ( !err.isEmpty() ) {
-        int s = KMessageBox::warningContinueCancelList( 0, i18n("P4 outputted errors during diff. Do you still want to continue?"),
+        int s = KMessageBox::warningContinueCancelList( 0, i18n("P4 output errors during diff. Do you still want to continue?"),
                         QStringList::split( "\n", err, false ), i18n("Errors During Diff") );
         if ( s != KMessageBox::Continue )
             return;
@@ -273,8 +276,8 @@ void PerforcePart::slotDiffFinished( const QString& diff, const QString& err )
     QString strippedDiff = diff;
     strippedDiff.replace( rx, QString::null );
 
-    Q_ASSERT( diffFrontend() );
-    diffFrontend()->showDiff( strippedDiff );
+    if (KDevDiffFrontend *diffFrontend = extension<KDevDiffFrontend>("KDevelop/DiffFrontend"))
+        diffFrontend->showDiff( strippedDiff );
 }
 
 QString PerforcePart::currentFile()
