@@ -30,6 +30,15 @@
 #include "subversion_core.h"
 #include "subversion_widget.h"
 #include "subversionprojectwidget.h"
+#include "subversion_fileinfo.h"
+#include "subversion_global.h"
+#include "kdevversioncontrol.h"
+#include "svn_fileselectdlg_commit.h"
+#include "svn_logviewwidget.h"
+#include "svn_switchwidget.h"
+#include "svn_copywidget.h"
+#include "svn_mergewidget.h"
+
 #include "urlutil.h"
 #include <qvbox.h>
 #include <kdialogbase.h>
@@ -43,6 +52,10 @@
 #include <qwidget.h>
 #include <kdevplugininfo.h>
 
+#include <kmessagebox.h>
+
+using namespace SvnGlobal;
+
 static const KDevPluginInfo data("kdevsubversion");
 
 typedef KDevGenericFactory<subversionPart> subversionFactory;
@@ -73,6 +86,7 @@ subversionPart::subversionPart(QObject *parent, const char *name, const QStringL
 	m_impl->processWidget()->setCaption(i18n( "Subversion Output" ));
 	mainWindow()->embedOutputView( (QWidget*)m_impl->processWidget(), i18n( "Subversion" ), i18n( "Subversion messages" ) );
     QWhatsThis::add((QWidget*)m_impl->processWidget(), i18n("<b>Subversion</b><p>Subversion operations window."));
+
 }
 
 subversionPart::~subversionPart() {
@@ -84,7 +98,7 @@ subversionPart::~subversionPart() {
 }
 
 void subversionPart::setupActions() {
-	actionCommit = new KAction( i18n("&Commit to Repository"), 0, this, SLOT(slotActionCommit()), actionCollection(), "subversion_commit" );
+	actionCommit = new KAction( i18n("&Commit to Repository..."), 0, this, SLOT(slotActionCommit()), actionCollection(), "subversion_commit" );
 	actionCommit->setToolTip( i18n("Commit file(s)") );
 	actionCommit->setWhatsThis( i18n("<b>Commit file(s)</b><p>Commits file to repository if modified.") );
 
@@ -96,6 +110,9 @@ void subversionPart::setupActions() {
 	actionAdd = new KAction( i18n("&Add to Repository"), 0, this, SLOT(slotActionAdd()), actionCollection(), "subversion_add" );
 	actionAdd->setToolTip( i18n("Add file to repository") );
 	actionAdd->setWhatsThis( i18n("<b>Add file to repository</b><p>Adds file to repository.") );
+	
+	actionLog = new KAction( i18n("Show logs..."), 0, this, SLOT(slotLog()), actionCollection(), "subversion_log" );
+	actionBlame = new KAction( i18n("Blame..."), 0, this, SLOT(slotBlame()), actionCollection(), "subversion_blame");
 
 	actionRemove = new KAction( i18n("&Remove From Repository"), 0, this, SLOT(slotActionDel()), actionCollection(), "subversion_remove" );
 	actionRemove->setToolTip( i18n("Remove from repository") );
@@ -133,6 +150,13 @@ void subversionPart::setupActions() {
 			this, SLOT(slotActionResolve()), actionCollection(), "subversion_resolve" );
 	actionResolve->setToolTip( i18n("Resolve the conflicting state of a file after a merge") );
 	actionResolve->setWhatsThis( i18n("<b>Resolve the conflicting state</b><p>Remove the conflict state that can be set on a file after a merge failed.") );
+	actionSwitch = new KAction( i18n("Switch this working copy to URL.."), 0,
+			this, SLOT(slotSwitch()), actionCollection(), "subversion_switch" );
+	// warn slogCopy(), slotMerge only works on context menu. There is no main-menu action
+	actionCopy = new KAction( i18n("Copy this working copy to URL.."), 0,
+								this, SLOT(slotCopy()), actionCollection(), "subversion_copy" );
+	actionMerge = new KAction( i18n("Merge difference to working copy"), 0,
+							  this, SLOT(slotMerge()), actionCollection(), "subversion_merge" );
 }
 
 QWidget* subversionPart::newProjectWidget( QWidget* parent ) {
@@ -201,7 +225,11 @@ if(!project())
         subMenu->setWhatsThis(id, i18n("<b>Add file to repository</b><p>Adds file to repository."));
 		id = subMenu->insertItem( actionRemove->text(), this, SLOT(slotDel()) );
         subMenu->setWhatsThis(id, i18n("<b>Remove from repository</b><p>Removes file(s) from repository."));
-
+		id = subMenu->insertItem( actionLog->text(), this, SLOT(slotLog()) );
+		subMenu->setWhatsThis(id, i18n("<b>Show logs..</b><p>View Logs"));
+		id = subMenu->insertItem( actionBlame->text(), this, SLOT(slotBlame()) );
+		subMenu->setWhatsThis(id, i18n("<b>Blame 0:HEAD </b><p>Show Annotate"));
+		
 		subMenu->insertSeparator();
 		id = subMenu->insertItem( actionDiffLocal->text(), this, SLOT(slotDiffLocal()) );
 		subMenu->setWhatsThis(id, i18n("<b>Diff</b><p>Diff file to local disk."));
@@ -215,6 +243,12 @@ if(!project())
 		subMenu->setWhatsThis(id, i18n("<b>Revert</b><p>Undo local changes.") );
 		id = subMenu->insertItem( actionResolve->text(), this, SLOT(slotResolve()) );
 		subMenu->setWhatsThis(id, i18n("<b>Resolve</b><p>Resolve conflicting state.") );
+		id = subMenu->insertItem( actionSwitch->text(), this, SLOT(slotSwitch()) );
+		subMenu->setWhatsThis(id, i18n("<b>Switch</b><p>Switch working tree.") );
+		id = subMenu->insertItem( actionCopy->text(), this, SLOT(slotCopy()) );
+		subMenu->setWhatsThis(id, i18n("<b>Copy</b><p>Copy from/between path/URLs") );
+		id = subMenu->insertItem( actionMerge->text(), this, SLOT(slotMerge()) );
+		subMenu->setWhatsThis(id, i18n("<b>Merge</b><p>Merge difference to working copy") );
 
 		/*
 		subMenu->insertSeparator();
@@ -263,11 +297,109 @@ void subversionPart::slotResolve() {
 	m_impl->resolve (m_urls);
 }
 
+void subversionPart::slotSwitch()
+{
+	if( m_urls.count() > 1 ){
+		KMessageBox::error( (QWidget*)project()->mainWindow()->main(),
+							i18n("Please select only one item for subversion switch") );
+		return;
+	}
+	if( m_urls.count() < 1 ) return;
+	
+	// retrieve repository info from local-copy metadata which will be displayed in dialog box
+	KURL wcPath = m_urls.first();
+	QMap< KURL, SvnGlobal::SvnInfoHolder> holderMap;
+	SvnGlobal::SvnInfoHolder holder;
+			
+	m_impl->clientInfo( wcPath, false, holderMap );
+	QValueList< SvnGlobal::SvnInfoHolder > holderList = holderMap.values();
+	holder = holderList.first();
+	// invoke dialog box
+	SvnSwitchDlg dlg( &holder, wcPath.path(), (QWidget*)project()->mainWindow()->main() );
+	
+	if( dlg.exec() != QDialog::Accepted ){
+		return;
+	}
+	// check target url's validity
+	KURL repositUrl = KURL( dlg.destUrl() );
+	if( !repositUrl.isValid() ){
+		KMessageBox::error( (QWidget*)project()->mainWindow()->main(),
+							 i18n("The destination URL is invalid") );
+		return;
+	}
+	// call core
+	if( dlg.switchOnly() )
+		m_impl->switchTree( wcPath, repositUrl, -1, "HEAD", dlg.recursive() );
+	else if( dlg.relocation() )
+		m_impl->switchRelocate( wcPath, dlg.currentUrl(), repositUrl, dlg.recursive() );
+	else
+		KMessageBox::error( (QWidget*)project()->mainWindow()->main(),
+							i18n("Fail to conduct subversion switch. No action was selected") );
+}
+
+void subversionPart::slotCopy()
+{
+	// error check
+	if( m_urls.count() > 1 ){
+		KMessageBox::error( (QWidget*)project()->mainWindow()->main(),
+							 i18n("Please select only one item for subversion switch") );
+		return;
+	}
+	if( m_urls.count() < 1 ) return;
+
+	// retrieve repository info from local-copy metadata which will be displayed in dialog box
+	KURL wcPath = m_urls.first();
+	QMap< KURL, SvnGlobal::SvnInfoHolder> holderMap;
+	SvnGlobal::SvnInfoHolder holder;
+	m_impl->clientInfo( wcPath, false, holderMap );
+	QValueList< SvnGlobal::SvnInfoHolder > holderList = holderMap.values();
+	holder = holderList.first();
+	// start input dialog
+	SvnCopyDialog dlg( wcPath.prettyURL(),
+					   &holder,
+					   (QWidget*)project()->mainWindow()->main());
+	
+	if( dlg.exec() != QDialog::Accepted )
+		return;
+	// retrieve user input
+	KURL srcUrl = dlg.sourceUrl();
+    int rev = dlg.revision();
+    QString revKind = dlg.revKind();
+    KURL dest = dlg.destUrl();
+
+	kdDebug(9036) << " SRC: " << srcUrl << " DEST: " << dest << " Revnum: " << rev << " RevKind: " << revKind << endl;
+
+	m_impl->svnCopy( srcUrl, rev, revKind, dest );
+}
+
+void subversionPart::slotMerge()
+{
+	// error check
+	if( m_urls.count() > 1 ){
+		KMessageBox::error( (QWidget*)project()->mainWindow()->main(),
+							 i18n("Please select only one item for subversion merge") );
+		return;
+	}
+	if( m_urls.count() < 1 ) return;
+
+	KURL wcTarget= m_urls.first();
+	SvnMergeDialog dlg( wcTarget, (QWidget*)project()->mainWindow()->main() );
+	if( dlg.exec() != QDialog::Accepted ) return;
+
+	KURL src1 = dlg.source1();
+	SvnRevision rev1 = dlg.rev1();
+	KURL src2 = dlg.source2();
+	SvnRevision rev2 = dlg.rev2();
+
+	m_impl->merge( src1, rev1.revNum, rev1.revKind, src2, rev2.revNum, rev2.revKind, wcTarget,
+				   dlg.recurse(), dlg.ignoreAncestry(), dlg.force(), dlg.dryRun() );
+}
+
 void subversionPart::slotActionCommit() {
 	kdDebug(9036) << "subversion: slotActionCommit()" << endl;
 	KURL doc;
 	if (urlFocusedDocument( doc )) {
-		m_impl->commit( doc );
+		m_impl->commit( doc, true, true );
 	}
 }
 
@@ -309,24 +441,82 @@ void subversionPart::slotActionDiffHead() {
 		m_impl->diff( doc, "HEAD" );
 	}
 }
-
-void subversionPart::slotCommit() {
-	m_impl->commit (m_urls);
+void subversionPart::slotCommit()
+{
+	SVNFileSelectDlgCommit dialog( m_urls, this, 0 );
+	if( dialog.exec() == QDialog::Accepted ){
+		KURL::List tobeCommittedUrls = dialog.checkedUrls();
+		bool recursive = dialog.recursive();
+		bool keepLocks = dialog.keepLocks();
+		m_impl->commit(tobeCommittedUrls, recursive, keepLocks );
+	}
+}
+void subversionPart::slotAdd() {
+	m_impl->add( m_urls );
 }
 
-void subversionPart::slotAdd() {
-	m_impl->add (m_urls);
+void subversionPart::slotLog()
+{
+	if (m_urls.count() > 1){
+		KMessageBox::error( (QWidget*)project()->mainWindow()->main(),
+							i18n("Please select only one item for subversion log") );
+		return;
+	}
+	SvnLogViewOptionDlg dlg;
+	if( dlg.exec() ){
+		int revstart = dlg.revstart();
+		QString revkindstart = dlg.revKindStart();
+		int revend = dlg.revend();
+		QString revkindend = dlg.revKindEnd();
+		bool reposit = dlg.repositLog();
+		bool strictNode = dlg.strictNode();
+		m_impl->svnLog (m_urls, revstart, revkindstart, revend, revkindend, reposit, true/*changedPath*/, strictNode);	
+	} else{
+		return;
+	}
+}
+void subversionPart::slotBlame()
+{
+	if (m_urls.count() > 1){
+		KMessageBox::error( (QWidget*)project()->mainWindow()->main(),
+							 i18n("Please select only one item to see annotate") );
+		return;
+	}
+	if (m_urls.count() < 1){
+		KMessageBox::error( (QWidget*)project()->mainWindow()->main(),
+							 i18n("Select file to see blame") );
+		return;
+	}
+	KURL url = m_urls.first();
+// 	m_impl->blame(url, repositBlame, int revstart, QString revKindStart, int revend, QString revKindEnd);
+	m_impl->blame(url, SvnGlobal::path_to_reposit, 0, "", -1, "HEAD");
 }
 
 void subversionPart::slotDel() {
 	m_impl->del (m_urls);
 }
 
+// note: currently diffAsync does not support merging. But svncore::diff()
+// cannot be invoked on directory, while diffAsync can.
 void subversionPart::slotDiffLocal() {
-	m_impl->diff (m_urls, "BASE");
+// 	m_impl->diff (m_urls, "BASE");
+	if( m_urls.count() < 1 ){
+		// Impossible to reach here but..
+		KMessageBox::error( (QWidget*)project()->mainWindow()->main(),
+							 i18n("Select file or directory to see diff") );
+		return;
+	}
+	m_impl->diffAsync( *(m_urls.begin()), *(m_urls.begin()), -1, "BASE", -1, "WORKING", true );
 }
 void subversionPart::slotDiffHead() {
-	m_impl->diff (m_urls, "HEAD");
+// 	m_impl->diff (m_urls, "HEAD");
+	if( m_urls.count() < 1 ){
+		// Impossible to reach here but..
+		KMessageBox::error( (QWidget*)project()->mainWindow()->main(),
+							 i18n("Select file or directory to see diff") );
+		return;
+	}
+	m_impl->diffAsync( *(m_urls.begin()), *(m_urls.begin()), -1, "WORKING", -1, "HEAD", true );
 }
 
 void subversionPart::slotRevert() {
