@@ -31,6 +31,10 @@ class subversionCore;
 class subversionOptionsWidget;
 class subversionProjectWidget;
 class Context;
+namespace SvnGlobal
+{
+class SvnInfoHolder;
+};
 
 class subversionPart : public KDevVersionControl
 {
@@ -51,6 +55,8 @@ public:
 		void setBaseURL(const KURL& url ) { base = url; }
 		KURL baseURL() { return base; }
 		virtual bool isValidDirectory( const QString &dirPath ) const;
+		KURL::List urls() { return m_urls; }
+        subversionCore* svncore() { return m_impl; }
 
 signals:
 //		void finishedFetching( QString destinationDir );
@@ -70,9 +76,14 @@ private slots:
 		void slotCommit();
 		void slotAdd();
 		void slotDel();
+		void slotLog();
+		void slotBlame();
 		void slotDiffLocal();
 		void slotDiffHead();
 		void slotResolve();
+		void slotSwitch();
+		void slotCopy();
+		void slotMerge();
 		void slotProjectClosed();
 		void slotProjectOpened();
 
@@ -84,17 +95,23 @@ private:
 		*actionDiffHead,
 		*actionDiffLocal,
 		*actionAdd,
+		*actionLog,
+		*actionBlame,
 		*actionRemove,
 		*actionUpdate,
 		//*actionAddToIgnoreList,
 		//*actionRemoveFromIgnoreList,
 		*actionRevert,
-		*actionResolve;
+		*actionResolve,
+		*actionSwitch,
+		*actionCopy,
+		*actionMerge;
 
 		QGuardedPtr<subversionProjectWidget> m_projWidget;
 		KURL base;
 
 public:
+        QMap< KURL, SvnGlobal::SvnInfoHolder > m_prjInfoMap;
 
 };
 
